NZLB = (1.02)^(1/4)-1; %the lower bound on (net) interest rates, in quarterly terms
pi_star=(1.02)^(1/4); %gross steady state inflation, in quarterly terms
rho = 0.8; %serial correlation of natural interest rate shock
e0 = -0.05; %shock to natural interest rates, in quarterly terms
sigma=0.157; %intertemporal elasticity of substitution, Woodford (1999)
beta=0.99; %households' discount factor (impatience), Woodford (1999)
potential_gdp_growth=0.02; %matching long-term real per capita gdp growth in the US economy
one_minus_alpha=0.7; %Cobb-Douglas exponent on labour, Smets Wouters (2002)
phi=0.25; %elasticity of labour supply, Smets Wouters (2003)
epsilon=3; %elasticity of substitution between labour varieties, Smets Wouters (2002)
theta=find_theta(0.024,beta,one_minus_alpha,phi,epsilon,sigma); %Calvo probability, set so as to match Woodford's kappa=0.024 under the rest given 

%compile the parameter set
parameter_set=[sigma,beta,potential_gdp_growth,pi_star-1,theta,one_minus_alpha,phi,epsilon];

tau=10;
alpha_cond=0.1;
k=2;

[resultsZLB_com,resultsPLB_com,lossz_com,lossp_com,lossz_dis,lossp_dis,kz,kp]=EW_ZLB_vs_PLB(NZLB,e0,tau,parameter_set,alpha_cond);

table_tau_EV=zeros(6,21,30);
how_many_alphas=99;
table_breakeven=zeros(how_many_alphas,9);

for jj=1:how_many_alphas
    alpha_cond=jj/100
    for ii=2:20
        tau=ii;
        [resultsZLB_com,resultsPLB_com,lossz_com,lossp_com,lossz_dis,lossp_dis,kz,kp]=EW_ZLB_vs_PLB(NZLB,e0,tau,parameter_set,alpha_cond);
        table_tau_EV(1,ii,jj)=tau;
        table_tau_EV(2,ii,jj)=lossz_com;
        table_tau_EV(3,ii,jj)=lossp_com;
        table_tau_EV(4,ii,jj)=lossz_dis;
        table_tau_EV(5,ii,jj)=lossp_dis;
        table_tau_EV(6,ii,jj)=alpha_cond*(1-alpha_cond)^(ii-1);
    end
    table_tau_EV(2,21,jj)=sum(table_tau_EV(2,:)'.*table_tau_EV(6,:)')/sum(table_tau_EV(6,:)');
    table_tau_EV(3,21,jj)=sum(table_tau_EV(3,:)'.*table_tau_EV(6,:)')/sum(table_tau_EV(6,:)');
    table_tau_EV(4,21,jj)=sum(table_tau_EV(4,:)'.*table_tau_EV(6,:)')/sum(table_tau_EV(6,:)');
    table_tau_EV(5,21,jj)=sum(table_tau_EV(5,:)'.*table_tau_EV(6,:)')/sum(table_tau_EV(6,:)');
    table_breakeven(jj,1)=alpha_cond;
end

for jj=1:how_many_alphas
    table_breakeven(jj,2)=table_tau_EV(2,21,10);
    table_breakeven(jj,3)=table_tau_EV(3,21,jj);
    table_breakeven(jj,4)=table_tau_EV(4,21,10);
    table_breakeven(jj,5)=table_tau_EV(5,21,jj);
    table_breakeven(jj,6)=table_tau_EV(2,21,10);
    table_breakeven(jj,7)=table_tau_EV(5,21,jj);
    table_breakeven(jj,8)=table_tau_EV(4,21,10);
    table_breakeven(jj,9)=table_tau_EV(3,21,jj);
end

descr={'alpha','C ZLB base alpha','C PLB','D ZLB base alpha','D PLB','C ZLB base alpha','D PLB','D ZLB base alpha','C PLB'};
xlswrite('Graphs/EW.xlsx',descr,1,'A1');
xlswrite('Graphs/EW.xlsx',table_breakeven,1,'A2');


