function [NKPC_PI,NKPC]=positive_inf_steady(beta,theta,one_minus_alpha,phi,epsilon,sigma,pi)

%based on Khan, Rudolf (2005) - notation in brackets, while arguments as in
%Gali (2008)

%beta: impatience of households (Beta)
%theta: Calvo probability (Alpha)
%one_minus_alpha: Cobb-Douglas exponent on labour (A)
%phi: Frisch elasticity of labour supply (Phi)
%epsilon: elasticity of substitution (Theta)
%sigma: CRRA (Sigma_inverted)
%pi: gross steady-state inflation (Pi)

%NKPC
alpha=1-one_minus_alpha;
NKPC = [beta, ((1-theta)*(1-beta*theta))/(theta)*(1-alpha)/(1-alpha+alpha*epsilon+phi*epsilon)*(sigma+(phi+alpha)/(1-alpha))];

%NKPC_PI
Beta=beta;
Pi=pi;
Phi=phi;

Alpha=theta;
A=one_minus_alpha;
Theta=epsilon;
Sigma_inverted=sigma;

Omega = (1+Phi-A)/A;

Beta_pi = Beta*((1-Alpha*(Pi^(Theta-1)))*(((Theta+Omega*Theta)/(1+Omega*Theta))*(Pi^(1+Omega*Theta))-(Theta-1)/(1+Omega*Theta))+Alpha*(Pi^(Theta+Omega*Theta)));
Kappa_pi = ((1-Alpha*(Pi^(Theta-1)))*(1-Alpha*Beta*(Pi^(Theta+Omega*Theta))))/(Alpha*(Pi^(Theta-1)))*(Omega+Sigma_inverted)/(1+Omega*Theta)+(Beta*(1-Alpha*(Pi^(Theta-1)))*(1-Pi^(1+Omega*Theta)))/(1+Omega*Theta);
Delta_pi = ((Pi^(1+Omega*Theta)-1)*Beta*(1-Alpha*(Pi^(Theta-1)))*(1-Alpha*Beta*(Pi^(Theta-1))))/(1+Omega*Theta);

Beta_1 = Beta_pi + Alpha*Beta*(Pi^(Theta-1));
Beta_2 = -Alpha*(Beta^2)*(Pi^(Theta+Omega*Theta));
Delta_1 = Delta_pi - Alpha*Beta*(Pi^(Theta-1))*Kappa_pi;

NKPC_PI = [Beta_1, Beta_2, Kappa_pi, Delta_1];



