function [baseline_loss] = run_commitment(NZLB,rho,e0,parameter_set)

%1 COMPUTE LOSS UNDER ZLB
%Run baseline simulation under ZERO lower bound
results_zero = solve_NZLB_com(0,rho,e0,parameter_set,0);
baseline_loss = sum(results_zero(:,9));
results_zero_dis = solve_NZLB_dis(0,rho,e0,parameter_set,0);
baseline_loss_dis = sum(results_zero_dis(:,7));
%Run baseline simulation under POSITIVE lower bound
[~] = solve_NZLB_com(NZLB,rho,e0,parameter_set,1,baseline_loss);


%2 SIMULATE POSITIVE LOWER BOUNDS AND PLOT SIMULATION RESULTS
showplot=0;
sizes=zeros(2,1);
NZLBs=zeros(2,1);
for ii = 0:1
	NZLB = ii*0.02/4;
	NZLBs(ii+1,1) = NZLB;
	eval(['results_',num2str(ii),'=solve_NZLB_com(NZLB,rho,e0,parameter_set,showplot);']);
	eval(['sizes(ii+1,1)=size(results_',num2str(ii),',1);']);
end
max_length=max(sizes);
results_sens_NZLB = NaN(max_length,9,2);
for ii = 0:1
	eval(['results_sens_NZLB(1:size(results_',num2str(ii),'),:,ii+1)=results_',num2str(ii),';']);
end

%3a SHOW OUTPUT GAP
figure(3)
plot(0:(max_length-1),results_sens_NZLB(:,2,1),'--k',...
0:(max_length-1),results_sens_NZLB(:,2,2),'-k')
legend('zero lower bound','lower bound=0.02/4')
title('Output gap with different lower bounds (commitment)')
%axis([0 (max_length-1)  -0.4 0.1]);
saveas(3,'Graphs/3_NZLB_sens_output_com.jpg','jpg');
y_zlb_com=results_sens_NZLB(:,2,1);
y_nzlb_com=results_sens_NZLB(:,2,2);
descr={'zero lower bound','lower bound=0.02/4'};
xlswrite('Graphs/data.xlsx',descr,3,'B1');
xlswrite('Graphs/data.xlsx',[results_sens_NZLB(:,2,1),results_sens_NZLB(:,2,2)],3,'B2');

%3b SHOW INFLATION
figure(4)
plot(0:(max_length-1),results_sens_NZLB(:,3,1),'--k',...
0:(max_length-1),results_sens_NZLB(:,3,2),'-k')
legend('zero lower bound','lower bound=0.02/4')
title('Inflation rate with different lower bounds (commitment)')
%axis([0 (max_length-1)  -0.3 0.1]);
saveas(4,'Graphs/4_NZLB_sens_inflation_com.jpg','jpg');
pi_zlb_com=results_sens_NZLB(:,3,1);
pi_nzlb_com=results_sens_NZLB(:,3,2);
descr={'zero lower bound','lower bound=0.02/4'};
xlswrite('Graphs/data.xlsx',descr,4,'B1');
xlswrite('Graphs/data.xlsx',[results_sens_NZLB(:,3,1),results_sens_NZLB(:,3,2)],4,'B2');

%3c SHOW NOMINAL INTEREST RATE
figure(5)
plot(0:(max_length-1),results_sens_NZLB(:,4,1),'--k',...
0:(max_length-1),results_sens_NZLB(:,4,2),'-k')
legend('zero lower bound','lower bound=0.02/4')
title('Nominal interest rate with different lower bounds (commitment)')
axis([0 (max_length-1)  -0.002 0.02]);
saveas(5,'Graphs/5_NZLB_sens_NIR_com.jpg','jpg');
i_zlb_com=results_sens_NZLB(:,4,1);
i_nzlb_com=results_sens_NZLB(:,4,2);
descr={'zero lower bound','lower bound=0.02/4'};
xlswrite('Graphs/data.xlsx',descr,5,'B1');
xlswrite('Graphs/data.xlsx',[results_sens_NZLB(:,4,1),results_sens_NZLB(:,4,2)],5,'B2');

save('crossgraphs.mat','y_zlb_com','y_nzlb_com','pi_zlb_com','pi_nzlb_com','i_zlb_com','i_nzlb_com');

%3d SHOW LM1
figure(6)
plot(0:(max_length-1),results_sens_NZLB(:,7,1),'--k',...
0:(max_length-1),results_sens_NZLB(:,7,2),'-k')
title('Lagrange multiplier 1 with different lower bounds (commitment)')
%axis([0 (max_length-1)  -0.3 0.1]);
saveas(6,'Graphs/6_NZLB_sens_PHI1_com.jpg','jpg');
descr={'zero lower bound','lower bound=0.02/4'};
xlswrite('Graphs/data.xlsx',descr,6,'B1');
xlswrite('Graphs/data.xlsx',[results_sens_NZLB(:,7,1),results_sens_NZLB(:,7,2)],6,'B2');

%4 BREAK-EVEN AUTOCORRELATIONS
beac=zeros(100,1);
for jj=0:99
	rho_be=jj/100;
	results1=solve_NZLB_com(NZLB,rho_be,e0,parameter_set,0);
	beac(jj+1,1)=sum(results1(:,9));
end

figure(7)
h1 = plot(linspace(0,0.99,100)',beac(:,1),'--k');
hold on
h2 = plot(linspace(0,0.99,100)',baseline_loss*ones(100,1),'-k');
legend('loss function value at NZLB=0.02/4 for a given rho','loss function value for ZLB and rho=0.8');
title('Loss equivalence of positive lower bound under lower autocorrelation of shock to natural interest rate (rho) - commitment');
xa_def = [0.5 0.5 0.8 0.8 0.5]; ya_def = [0.0002 0.002 0.002 0.0002 0.0002];
h5 = fill(xa_def,ya_def,[0.9 0.9 0.9], 'LineStyle', 'none');
set(gca, 'Children', [h1 h2 h5])
%axis([0 (max_length-1)  -0.3 0.1]);
saveas(7,'Graphs/7_BE_AC_com.jpg','jpg');
descr={'rho','loss function value at NZLB=0.02/4 for a given rho','loss function value for ZLB and rho=0.8'};
xlswrite('Graphs/data.xlsx',descr,7,'B1');
xlswrite('Graphs/data.xlsx',[linspace(0,0.99,100)',beac(:,1),baseline_loss*ones(100,1)],7,'B2');

%4a LAYERS OF LOSS wrt. RHO and LB
layers=zeros(100,100);
rhos=(0:99)/100;
LBs=linspace(-0.02,0.04,100)/4;
for jj=1:100
    rho_now=rhos(jj);
    jj
    for kk=1:100
        LB_now=LBs(kk);
        resultsGER=solve_NZLB_com(LB_now,rho_now,e0,parameter_set,0);
        layers(jj,kk)=sum(resultsGER(:,9));
    end
end

descr={'rho\LB (loss under comm)'};
xlswrite('Graphs/data.xlsx',descr,31,'B1');
xlswrite('Graphs/data.xlsx',LBs,31,'C1');
xlswrite('Graphs/data.xlsx',[rhos',layers],31,'B2');

%5 BEAK-EVEN SHOCK SIZES
bess=zeros(31,1);
for jj=1:31
	e0_be=-(jj+19)/1000;
	results3=solve_NZLB_com(NZLB,rho,e0_be,parameter_set,0);
	bess(jj,1)=sum(results3(:,9));
end

figure(8)
plot(linspace(0.02,0.05,31)',bess(:,1),'--k',...
linspace(0.02,0.05,31)',baseline_loss*ones(31,1),'-k')
legend('loss function value at NZLB=0.02/4 for a given e0','loss function value for ZLB and e0=0.05')
title('Loss equivalence of positive lower bound under lower size of shock to natural interest rate (e0) - commitment');
%axis([0 (max_length-1)  -0.3 0.1]);
saveas(8,'Graphs/8_BE_SS_com.jpg','jpg');
descr={'e1','loss function value at NZLB=0.02/4 for a given e0','loss function value for ZLB and e0=0.05'};
xlswrite('Graphs/data.xlsx',descr,8,'B1');
xlswrite('Graphs/data.xlsx',[linspace(0.02,0.05,31)',bess(:,1),baseline_loss*ones(31,1)],8,'B2');

%6 SENSITIVITY TABLES
rho_sensit=linspace(0.5,0.9,9)';
nzlb_sensit=linspace(0.001,0.02/4,5)';
e0_sensit=linspace(-0.02,-0.10,9)';
epsilon_sensit=[0.1; 1.1; 2; 3; 5; 10; 100];
potential_gdp_growth_sensit = [0.04; 0.03; 0.02;0.01;0.00];
pi_star_sensit = [(1.02)^(1/4); (1.03)^(1/4); (1.04)^(1/4)];
theta_sensit = linspace(0.4,0.9,11)';
theta_sensit(8)=parameter_set(5);
phi_sensit = [0.1; 0.25; 0.5; 1; 2; 3; 5];
accuracy1=1000;
accuracy2=10000;
filename = 'Tables/sensitivity_com.xlsx';

%6a: rows - NZLB, columns - baseline rho, content: break-even rho
table1=zeros(size(nzlb_sensit,1),size(rho_sensit,1));
for ii=1:size(rho_sensit,1)
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_com(0,rho_sensit(ii),e0,parameter_set,0);
        loss_0=sum(results_0(:,9));
        rho_1=rho_sensit(ii);
        results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set,0);
        loss_1=sum(results_1(:,9));
        while (loss_1>=loss_0 && rho_1>=0)
            rho_1=rho_1-1/accuracy1;
            results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set,0);
            loss_1=sum(results_1(:,9));
            if loss_1>=loss_0 && rho_1<0
                rho_1=NaN;
            end
        end
        table1(jj,ii)=rho_1;
    end
end
sensitivity1=[NaN,rho_sensit';nzlb_sensit,table1];
descr={'break-even rho','','baseline rho';'','','',;'PLB','',''};
xlswrite(filename,descr,1,'A1');
xlswrite(filename,sensitivity1,1,'B2');
display('Sensitivity table 1 saved - commitment');

%6b: rows - NZLB, columns - lambda, content: break-even rho
table2=zeros(size(nzlb_sensit,1),size(epsilon_sensit,1));
info_lambda=zeros(1,size(epsilon_sensit,1));
for ii=1:size(epsilon_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,8)=epsilon_sensit(ii,1);
    [~,NKPC]=positive_inf_steady(parameter_set_sensit(1,2),parameter_set_sensit(1,5),parameter_set_sensit(1,6),parameter_set_sensit(1,7),parameter_set_sensit(1,8),parameter_set_sensit(1,1),parameter_set_sensit(1,4)+1);
    info_lambda(1,ii)=NKPC(1,2)/epsilon_sensit(ii,1);
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_com(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,9));
        rho_1=rho;
        results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
        loss_1=sum(results_1(:,9));
        while (loss_1>=loss_0 && rho_1>=0)
            rho_1=rho_1-1/accuracy1;
            results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
            loss_1=sum(results_1(:,9));
            if loss_1>=loss_0 && rho_1<0
                rho_1=NaN;
            end
        end
        table2(jj,ii)=rho_1;
    end
end
sensitivity2=[NaN,epsilon_sensit';nzlb_sensit,table2];
descr={'','','implied lambda';'','','';'break-even rho','','epsilon';'','','',;'PLB','',''};
xlswrite(filename,descr,2,'A1');
xlswrite(filename,info_lambda,2,'C2');
xlswrite(filename,sensitivity2,2,'B4');
display('Sensitivity table 2 saved - commitment');

%6c: rows - NZLB, columns - baseline e0, content: break-even e0
table3=zeros(size(nzlb_sensit,1),size(e0_sensit,1));
for ii=1:size(e0_sensit,1)
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_com(0,rho,e0_sensit(ii),parameter_set,0);
        loss_0=sum(results_0(:,9));
        e0_1=e0_sensit(ii);
        results_1=solve_NZLB_com(nzlb_sensit(jj),rho,e0_1,parameter_set,0);
        loss_1=sum(results_1(:,9));
        while (loss_1>=loss_0 && e0_1<=0)
            e0_1=e0_1+1/accuracy2;
            results_1=solve_NZLB_com(nzlb_sensit(jj),rho,e0_1,parameter_set,0);
            loss_1=sum(results_1(:,9));
            if loss_1>=loss_0 && e0_1>0
                e0_1=NaN;
            end
        end
        table3(jj,ii)=e0_1;
    end
end
sensitivity3=[NaN,e0_sensit';nzlb_sensit,table3];
descr={'break-even e1','','baseline e1';'','','',;'PLB','',''};
xlswrite(filename,descr,3,'A1');
xlswrite(filename,sensitivity3,3,'B2');
display('Sensitivity table 3 saved - commitment');

%6d: rows - NZLB, columns - lambda, content: break-even e0
table4=zeros(size(nzlb_sensit,1),size(epsilon_sensit,1));
for ii=1:size(epsilon_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,8)=epsilon_sensit(ii,1);
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_com(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,9));
        e0_1=e0;
        results_1=solve_NZLB_com(nzlb_sensit(jj),rho,e0_1,parameter_set_sensit,0);
        loss_1=sum(results_1(:,9));
        while (loss_1>=loss_0 && e0_1<=0)
            e0_1=e0_1+1/accuracy2;
            results_1=solve_NZLB_com(nzlb_sensit(jj),rho,e0_1,parameter_set_sensit,0);
            loss_1=sum(results_1(:,9));
            if loss_1>=loss_0 && e0_1>0
                e0_1=NaN;
            end
        end
        table4(jj,ii)=e0_1;
    end
end
sensitivity4=[NaN,epsilon_sensit';nzlb_sensit,table4];
descr={'','','implied lambda';'','','';'break-even e1','','epsilon';'','','',;'PLB','',''};
xlswrite(filename,descr,4,'A1');
xlswrite(filename,info_lambda,4,'C2');
xlswrite(filename,sensitivity4,4,'B4');
display('Sensitivity table 4 saved - commitment');

%6e: rows - NZLB, columns - potential gdp growth, content: break-even rho
table5=zeros(size(nzlb_sensit,1),size(potential_gdp_growth_sensit,1));
for ii=1:size(potential_gdp_growth_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,3)=potential_gdp_growth_sensit(ii,1);
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_com(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,9));
        rho_1=rho;
        results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
        loss_1=sum(results_1(:,9));
        while (loss_1>=loss_0 && rho_1>=0)
            rho_1=rho_1-1/accuracy1;
            results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
            loss_1=sum(results_1(:,9));
            if loss_1>=loss_0 && rho_1<0
                rho_1=NaN;
            end
        end
        table5(jj,ii)=rho_1;
    end
end
sensitivity5=[NaN,potential_gdp_growth_sensit';nzlb_sensit,table5];
descr={'break-even rho','','potential gdp growth';'','','',;'PLB','',''};
xlswrite(filename,descr,5,'A1');
xlswrite(filename,sensitivity5,5,'B2');
display('Sensitivity table 5 saved - commitment');

%6f: rows - NZLB, columns - pi_star, content: break-even rho
table6=zeros(size(nzlb_sensit,1),size(pi_star_sensit,1));
for ii=1:size(pi_star_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,4)=pi_star_sensit(ii,1)-1;
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_com(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,9));
        rho_1=rho;
        results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
        loss_1=sum(results_1(:,9));
        while (loss_1>=loss_0 && rho_1>=0)
            rho_1=rho_1-1/accuracy1;
            results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
            loss_1=sum(results_1(:,9));
            if loss_1>=loss_0 && rho_1<0
                rho_1=NaN;
            end
        end
        table6(jj,ii)=rho_1;
    end
end
sensitivity6=[NaN,(((pi_star_sensit).^4)-ones(size(pi_star_sensit,1),size(pi_star_sensit,2)))';nzlb_sensit,table6];
descr={'break-even rho','','pi star';'','','',;'PLB','',''};
xlswrite(filename,descr,6,'A1');
xlswrite(filename,sensitivity6,6,'B2');
display('Sensitivity table 6 saved - commitment');

%6g: rows - NZLB, columns - theta, content: break-even rho
table7=zeros(size(nzlb_sensit,1),size(theta_sensit,1));
for ii=1:size(theta_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,5)=theta_sensit(ii,1);
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_com(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,9));
        rho_1=rho;
        results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
        loss_1=sum(results_1(:,9));
        while (loss_1>=loss_0 && rho_1>=0)
            rho_1=rho_1-1/accuracy1;
            results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
            loss_1=sum(results_1(:,9));
            if loss_1>=loss_0 && rho_1<0
                rho_1=NaN;
            end
        end
        table7(jj,ii)=rho_1;
    end
end
sensitivity7=[NaN,theta_sensit';nzlb_sensit,table7];
descr={'break-even rho','','theta';'','','',;'PLB','',''};
xlswrite(filename,descr,7,'A1');
xlswrite(filename,sensitivity7,7,'B2');
display('Sensitivity table 7 saved - commitment');

%6h: rows - NZLB, columns - phi, content: break-even rho
table8=zeros(size(nzlb_sensit,1),size(phi_sensit,1));
for ii=1:size(phi_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,7)=phi_sensit(ii,1);
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_com(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,9));
        rho_1=rho;
        results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
        loss_1=sum(results_1(:,9));
        while (loss_1>=loss_0 && rho_1>=0)
            rho_1=rho_1-1/accuracy1;
            results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
            loss_1=sum(results_1(:,9));
            if loss_1>=loss_0 && rho_1<0
                rho_1=NaN;
            end
        end
        table8(jj,ii)=rho_1;
    end
end
sensitivity8=[NaN,phi_sensit';nzlb_sensit,table8];
descr={'break-even rho','','phi';'','','',;'PLB','',''};
xlswrite(filename,descr,8,'A1');
xlswrite(filename,sensitivity8,8,'B2');
display('Sensitivity table 8 saved - commitment');

%6i: rows - NZLB, columns - baseline rho, content: break-even rho vs
%discretion (etc. till table 16)
table9=zeros(size(nzlb_sensit,1),size(rho_sensit,1));
for ii=1:size(rho_sensit,1)
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_dis(0,rho_sensit(ii),e0,parameter_set,0);
        loss_0=sum(results_0(:,7));
        rho_1=rho_sensit(ii);
        results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set,0);
        loss_1=sum(results_1(:,9));
        while (loss_1<=loss_0 && rho_1>=0 && rho_1<=1)
            rho_1=rho_1+1/accuracy1;
            results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set,0);
            loss_1=sum(results_1(:,9));
            if loss_1<=loss_0 && rho_1>1
                rho_1=NaN;
            end
        end
        table9(jj,ii)=rho_1;
    end
end
sensitivity9=[NaN,rho_sensit';nzlb_sensit,table9];
descr={'break-even rho vs discretion','','baseline rho';'','','',;'PLB','',''};
xlswrite(filename,descr,9,'A1');
xlswrite(filename,sensitivity9,9,'B2');
display('Sensitivity table 9 saved - commitment');

%6j: rows - NZLB, columns - lambda, content: break-even rho
table10=zeros(size(nzlb_sensit,1),size(epsilon_sensit,1));
info_lambda=zeros(1,size(epsilon_sensit,1));
for ii=1:size(epsilon_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,8)=epsilon_sensit(ii,1);
    [~,NKPC]=positive_inf_steady(parameter_set_sensit(1,2),parameter_set_sensit(1,5),parameter_set_sensit(1,6),parameter_set_sensit(1,7),parameter_set_sensit(1,8),parameter_set_sensit(1,1),parameter_set_sensit(1,4)+1);
    info_lambda(1,ii)=NKPC(1,2)/epsilon_sensit(ii,1);
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_dis(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,7));
        rho_1=rho;
        results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
        loss_1=sum(results_1(:,9));
        while (loss_1<=loss_0 && rho_1>=0 && rho_1<=1)
            rho_1=rho_1+1/accuracy1;
            results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
            loss_1=sum(results_1(:,9));
            if loss_1<=loss_0 && rho_1>1
                rho_1=NaN;
            end
        end
        table10(jj,ii)=rho_1;
    end
end
sensitivity10=[NaN,epsilon_sensit';nzlb_sensit,table10];
descr={'','','implied lambda';'','','';'break-even rho vs discretion','','epsilon';'','','',;'PLB','',''};
xlswrite(filename,descr,10,'A1');
xlswrite(filename,info_lambda,10,'C2');
xlswrite(filename,sensitivity10,10,'B4');
display('Sensitivity table 10 saved - commitment');

%6k: rows - NZLB, columns - baseline e0, content: break-even e0
table11=zeros(size(nzlb_sensit,1),size(e0_sensit,1));
for ii=1:size(e0_sensit,1)
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_dis(0,rho,e0_sensit(ii),parameter_set,0);
        loss_0=sum(results_0(:,7));
        e0_1=e0_sensit(ii);
        results_1=solve_NZLB_com(nzlb_sensit(jj),rho,e0_1,parameter_set,0);
        loss_1=sum(results_1(:,9));
        while (loss_1<=loss_0 && e0_1<=0)
            e0_1=e0_1-1/accuracy2;
            results_1=solve_NZLB_com(nzlb_sensit(jj),rho,e0_1,parameter_set,0);
            loss_1=sum(results_1(:,9));
        end
        table11(jj,ii)=e0_1;
    end
end
sensitivity11=[NaN,e0_sensit';nzlb_sensit,table11];
descr={'break-even e1 vs discretion','','baseline e1';'','','',;'PLB','',''};
xlswrite(filename,descr,11,'A1');
xlswrite(filename,sensitivity11,11,'B2');
display('Sensitivity table 11 saved - commitment');

%6l: rows - NZLB, columns - lambda, content: break-even e0
table12=zeros(size(nzlb_sensit,1),size(epsilon_sensit,1));
for ii=1:size(epsilon_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,8)=epsilon_sensit(ii,1);
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_dis(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,7));
        e0_1=e0;
        results_1=solve_NZLB_com(nzlb_sensit(jj),rho,e0_1,parameter_set_sensit,0);
        loss_1=sum(results_1(:,9));
        while (loss_1<=loss_0 && e0_1<=0)
            e0_1=e0_1-1/accuracy2;
            results_1=solve_NZLB_com(nzlb_sensit(jj),rho,e0_1,parameter_set_sensit,0);
            loss_1=sum(results_1(:,9));
        end
        table12(jj,ii)=e0_1;
    end
end
sensitivity12=[NaN,epsilon_sensit';nzlb_sensit,table12];
descr={'','','implied lambda';'','','';'break-even e1 vs discretion','','epsilon';'','','',;'PLB','',''};
xlswrite(filename,descr,12,'A1');
xlswrite(filename,info_lambda,12,'C2');
xlswrite(filename,sensitivity12,12,'B4');
display('Sensitivity table 12 saved - commitment');

%6m: rows - NZLB, columns - potential gdp growth, content: break-even rho
table13=zeros(size(nzlb_sensit,1),size(potential_gdp_growth_sensit,1));
for ii=1:size(potential_gdp_growth_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,3)=potential_gdp_growth_sensit(ii,1);
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_dis(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,7));
        rho_1=rho;
        results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
        loss_1=sum(results_1(:,9));
        while (loss_1<=loss_0 && rho_1>=0 && rho_1<=1)
            rho_1=rho_1+1/accuracy1;
            results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
            loss_1=sum(results_1(:,9));
            if loss_1<=loss_0 && rho_1>1
                rho_1=NaN;
            end
        end
        table13(jj,ii)=rho_1;
    end
end
sensitivity13=[NaN,potential_gdp_growth_sensit';nzlb_sensit,table13];
descr={'break-even rho vs discretion','','potential gdp growth';'','','',;'PLB','',''};
xlswrite(filename,descr,13,'A1');
xlswrite(filename,sensitivity13,13,'B2');
display('Sensitivity table 13 saved - commitment');

%6n: rows - NZLB, columns - pi_star, content: break-even rho
table14=zeros(size(nzlb_sensit,1),size(pi_star_sensit,1));
for ii=1:size(pi_star_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,4)=pi_star_sensit(ii,1)-1;
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_dis(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,7));
        rho_1=rho;
        results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
        loss_1=sum(results_1(:,9));
        while (loss_1<=loss_0 && rho_1>=0 && rho_1<=1)
            rho_1=rho_1+1/accuracy1;
            results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
            loss_1=sum(results_1(:,9));
            if loss_1<=loss_0 && rho_1>1
                rho_1=NaN;
            end
        end
        table14(jj,ii)=rho_1;
    end
end
sensitivity14=[NaN,(((pi_star_sensit).^4)-ones(size(pi_star_sensit,1),size(pi_star_sensit,2)))';nzlb_sensit,table14];
descr={'break-even rho vs discretion','','pi star';'','','',;'PLB','',''};
xlswrite(filename,descr,14,'A1');
xlswrite(filename,sensitivity14,14,'B2');
display('Sensitivity table 14 saved - commitment');

%6o: rows - NZLB, columns - theta, content: break-even rho
table15=zeros(size(nzlb_sensit,1),size(theta_sensit,1));
for ii=1:size(theta_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,5)=theta_sensit(ii,1);
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_dis(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,7));
        rho_1=rho;
        results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
        loss_1=sum(results_1(:,9));
        while (loss_1<=loss_0 && rho_1>=0 && rho_1<=1)
            rho_1=rho_1+1/accuracy1;
            results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
            loss_1=sum(results_1(:,9));
            if loss_1<=loss_0 && rho_1>1
                rho_1=NaN;
            end
        end
        table15(jj,ii)=rho_1;
    end
end
sensitivity15=[NaN,theta_sensit';nzlb_sensit,table15];
descr={'break-even rho vs discretion','','theta';'','','',;'PLB','',''};
xlswrite(filename,descr,15,'A1');
xlswrite(filename,sensitivity15,15,'B2');
display('Sensitivity table 15 saved - commitment');

%6p: rows - NZLB, columns - phi, content: break-even rho
table16=zeros(size(nzlb_sensit,1),size(phi_sensit,1));
for ii=1:size(phi_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,7)=phi_sensit(ii,1);
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_dis(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,7));
        rho_1=rho;
        results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
        loss_1=sum(results_1(:,9));
        while (loss_1<=loss_0 && rho_1>=0 && rho_1<=1)
            rho_1=rho_1+1/accuracy1;
            results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
            loss_1=sum(results_1(:,9));
            if loss_1<=loss_0 && rho_1>1
                rho_1=NaN;
            end
        end
        table16(jj,ii)=rho_1;
    end
end
sensitivity16=[NaN,phi_sensit';nzlb_sensit,table16];
descr={'break-even rho vs discretion','','phi';'','','',;'PLB','',''};
xlswrite(filename,descr,16,'A1');
xlswrite(filename,sensitivity16,16,'B2');
display('Sensitivity table 16 saved - commitment');

%6r: rows - NZLB, columns - baseline e0, content: break-even rho
table17=zeros(size(nzlb_sensit,1),size(e0_sensit,1));
for ii=1:size(e0_sensit,1)
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_com(0,rho,e0_sensit(ii),parameter_set,0);
        loss_0=sum(results_0(:,9));
        rho_1=rho;
        results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0_sensit(ii),parameter_set,0);
        loss_1=sum(results_1(:,9));
        while (loss_1>=loss_0 && rho_1>=0)
            rho_1=rho_1-1/accuracy1;
            results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0_sensit(ii),parameter_set,0);
            loss_1=sum(results_1(:,9));
            if loss_1>=loss_0 && rho_1<0
                rho_1=NaN;
            end
        end
        table17(jj,ii)=rho_1;
    end
end
sensitivity17=[NaN,e0_sensit';nzlb_sensit,table17];
descr={'break-even rho','','baseline e1';'','','',;'PLB','',''};
xlswrite(filename,descr,17,'A1');
xlswrite(filename,sensitivity17,17,'B2');
display('Sensitivity table 17 saved - commitment');

%6s: rows - NZLB, columns - baseline e0, content: break-even rho
table18=zeros(size(nzlb_sensit,1),size(e0_sensit,1));
for ii=1:size(e0_sensit,1)
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_dis(0,rho,e0_sensit(ii),parameter_set,0);
        loss_0=sum(results_0(:,7));
        rho_1=rho;
        results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0_sensit(ii),parameter_set,0);
        loss_1=sum(results_1(:,9));
        while (loss_1<=loss_0 && rho_1>=0 && rho_1<=1)
            rho_1=rho_1+1/accuracy1;
            results_1=solve_NZLB_com(nzlb_sensit(jj),rho_1,e0_sensit(ii),parameter_set,0);
            loss_1=sum(results_1(:,9));
            if loss_1<=loss_0 && rho_1>1
                rho_1=NaN;
            end
        end
        table18(jj,ii)=rho_1;
    end
end
sensitivity18=[NaN,e0_sensit';nzlb_sensit,table18];
descr={'break-even rho vs discretion','','baseline e1';'','','',;'PLB','',''};
xlswrite(filename,descr,18,'A1');
xlswrite(filename,sensitivity18,18,'B2');
display('Sensitivity table 18 saved - commitment');

%7 RHO/E0 TRADE-OFF UNDER PLB/ZLB
rho_grid=linspace(0.5,0.9,41)';
e0_results=zeros(size(rho_grid,1),2);

for ii=1:size(rho_grid,1)
    e0_seek1=e0;
%     results_1=solve_NZLB_com(0,rho_grid(ii),e0,parameter_set,0);
%     loss_1=sum(results_1(:,9));
    results_2=solve_NZLB_com(NZLB,rho_grid(ii),e0,parameter_set,0);
    loss_2=sum(results_2(:,9));
    while (loss_2>baseline_loss)
        e0_seek1=e0_seek1+1/accuracy2;
        results_2=solve_NZLB_com(NZLB,rho_grid(ii),e0_seek1,parameter_set,0);
        loss_2=sum(results_2(:,9));
    end
    while (loss_2<baseline_loss)
        e0_seek1=e0_seek1-1/accuracy2;
        results_2=solve_NZLB_com(NZLB,rho_grid(ii),e0_seek1,parameter_set,0);
        loss_2=sum(results_2(:,9));
    end
    e0_seek2=e0;
    while (loss_2>baseline_loss_dis)
        e0_seek2=e0_seek2+1/accuracy2;
        results_2=solve_NZLB_com(NZLB,rho_grid(ii),e0_seek2,parameter_set,0);
        loss_2=sum(results_2(:,9));
    end
    while (loss_2<baseline_loss_dis)
        e0_seek2=e0_seek2-1/accuracy2;
        results_2=solve_NZLB_com(NZLB,rho_grid(ii),e0_seek2,parameter_set,0);
        loss_2=sum(results_2(:,9));
    end
    e0_results(ii,1)=e0_seek1;
    e0_results(ii,2)=e0_seek2;
end

%commented version - with ZLB
% figure(16)
% plot(rho_grid,e0_results(:,1),'--k',...
% rho_grid,e0_results(:,2),':k',...
% rho_grid,e0*ones(size(rho_grid,1),1),'-k')
% xlabel('rho')
% ylabel('e1')
% legend('ZLB','PLB','baseline e1')
% title('Loss equivalence: baseline ZLB scenario vs ZLB and PLB under different rho and e1 -- commitment');
% %axis([0 (max_length-1)  -0.3 0.1]);
% saveas(16,'Graphs/16_equivalence_com.jpg','jpg');
% display('Rho/e0 graph created - commitment');

figure(16)
plot(rho_grid,e0_results(:,1),'--k',...
rho_grid,e0*ones(size(rho_grid,1),1),'-k')
xlabel('rho')
ylabel('e1')
legend('PLB','baseline e1','Location','South')
title('Line of equivalent loss under PLB -- commitment');
%axis([0 (max_length-1)  -0.3 0.1]);
saveas(16,'Graphs/16_equivalence_com.jpg','jpg');
display('Rho/e0 graph created - commitment');
descr={'rho','PLB','baseline e1'};
xlswrite('Graphs/data.xlsx',descr,16,'B1');
xlswrite('Graphs/data.xlsx',[rho_grid,e0_results(:,1),e0*ones(size(rho_grid,1),1)],16,'B2');

equiv_com_plb=e0_results(:,1);
equiv_com_plb_vsDis=e0_results(:,2);
e0_line=e0*ones(size(rho_grid,1),1);
save('crossgraphs3.mat','equiv_com_plb','equiv_com_plb_vsDis','e0_line','rho_grid');

beac=zeros(99,1);
parameter_set_alt1=[parameter_set(1,1),parameter_set(1,2),0.04,(1.04)^(1/4)-1,0.4,parameter_set(1,6),5,1.1];
results1z=solve_NZLB_com(0,rho,e0,parameter_set_alt1,0);
loss1z=sum(results1z(:,9));
for jj=0:99
	rho_be=jj/100;
    results1=solve_NZLB_com(NZLB,rho_be,e0,parameter_set_alt1,0);
	beac(jj+1,1)=sum(results1(:,9));
end

figure(28)
h1 = plot(linspace(0,0.99,100)',beac(:,1),'--k');
hold on
%h2 = plot(linspace(0,0.99,100)',beac(:,2)/loss2z,'-k');
h2 = plot(linspace(0,0.99,100)',loss1z*ones(100,1),'-k');
legend('PLB under commitment, growth=0.04, inf.target=0.04, theta=0.4, phi=5, epsilon=1.1','ZLB under commitment, baseline rho and the same parametrisation');
title('Loss under positive lower bound under different parameters, as a function of rho');
xa_def = [0.5 0.5 0.8 0.8 0.5]; ya_def = [0.0002 0.045 0.045 0.0002 0.0002];
h5 = fill(xa_def,ya_def,[0.9 0.9 0.9], 'LineStyle', 'none');
set(gca, 'Children', [h1 h2 h5])
%axis([0 (max_length-1)  -0.3 0.1]);
saveas(28,'Graphs/28_BE_AC_com.jpg','jpg');
descr={'rho','loss function value set 1, commitment','loss function value set 2, commitment'};
xlswrite('Graphs/data.xlsx',descr,28,'B1');
xlswrite('Graphs/data.xlsx',[linspace(0,0.99,100)',beac(:,1),loss1z*ones(100,1)],28,'B2');

