function [baseline_loss] = run_discretion(NZLB,rho,e0,parameter_set)

%1 COMPUTE LOSS UNDER ZLB
%Run baseline simulation under ZERO lower bound
results_zero = solve_NZLB_dis(0,rho,e0,parameter_set,0);
baseline_loss = sum(results_zero(:,7));
results_zero_com = solve_NZLB_com(0,rho,e0,parameter_set,0);
baseline_loss_com = sum(results_zero_com(:,9));
%Run baseline simulation under POSITIVE lower bound
[~] = solve_NZLB_dis(NZLB,rho,e0,parameter_set,1,baseline_loss);

%2 SIMULATE POSITIVE LOWER BOUNDS AND PLOT SIMULATION RESULTS
showplot=0;
sizes=zeros(2,1);
NZLBs=zeros(2,1);
for ii = 0:1
	NZLB = ii*0.02/4;
	NZLBs(ii+1,1) = NZLB;
	eval(['results_',num2str(ii),'=solve_NZLB_dis(NZLB,rho,e0,parameter_set,showplot);']);
	eval(['sizes(ii+1,1)=size(results_',num2str(ii),',1);']);
end
max_length=max(sizes);
results_sens_NZLB = NaN(max_length,7,2);
for ii = 0:1
	eval(['results_sens_NZLB(1:size(results_',num2str(ii),'),:,ii+1)=results_',num2str(ii),';']);
end

%3a SHOW OUTPUT GAP
figure(11)
plot(0:(max_length-1),results_sens_NZLB(:,2,1),'--k',...
0:(max_length-1),results_sens_NZLB(:,2,2),'-k')
legend('zero lower bound','lower bound=0.02/4')
title('Output gap with different lower bounds (discretion)')
axis([0 (max_length-1)  -1.2 0.1]);
saveas(11,'Graphs/11_NZLB_sens_output_dis.jpg','jpg');
y_zlb_dis=results_sens_NZLB(:,2,1);
y_nzlb_dis=results_sens_NZLB(:,2,2);
descr={'zero lower bound','lower bound=0.02/4'};
xlswrite('Graphs/data.xlsx',descr,11,'B1');
xlswrite('Graphs/data.xlsx',[results_sens_NZLB(:,2,1),results_sens_NZLB(:,2,2)],11,'B2');

%3b SHOW INFLATION
figure(12)
plot(0:(max_length-1),results_sens_NZLB(:,3,1),'--k',...
0:(max_length-1),results_sens_NZLB(:,3,2),'-k')
legend('zero lower bound','lower bound=0.02/4')
title('Inflation rate with different lower bounds (discretion)')
%axis([0 (max_length-1)  -0.3 0.1]);
saveas(12,'Graphs/12_NZLB_sens_inflation_dis.jpg','jpg');
pi_zlb_dis=results_sens_NZLB(:,3,1);
pi_nzlb_dis=results_sens_NZLB(:,3,2);
descr={'zero lower bound','lower bound=0.02/4'};
xlswrite('Graphs/data.xlsx',descr,12,'B1');
xlswrite('Graphs/data.xlsx',[results_sens_NZLB(:,3,1),results_sens_NZLB(:,3,2)],12,'B2');

%3c SHOW NOMINAL INTEREST RATE
figure(13)
plot(0:(max_length-1),results_sens_NZLB(:,4,1),'--k',...
0:(max_length-1),results_sens_NZLB(:,4,2),'-k')
legend('zero lower bound','lower bound=0.02/4')
title('Nominal interest rate with different lower bounds (discretion)')
axis([0 (max_length-1)  -0.002 0.02]);
saveas(13,'Graphs/13_NZLB_sens_NIR_dis.jpg','jpg');
i_zlb_dis=results_sens_NZLB(:,4,1);
i_nzlb_dis=results_sens_NZLB(:,4,2);
descr={'zero lower bound','lower bound=0.02/4'};
xlswrite('Graphs/data.xlsx',descr,13,'B1');
xlswrite('Graphs/data.xlsx',[results_sens_NZLB(:,4,1),results_sens_NZLB(:,4,2)],13,'B2');

save('crossgraphs2.mat','y_zlb_dis','y_nzlb_dis','pi_zlb_dis','pi_nzlb_dis','i_zlb_dis','i_nzlb_dis');

%4 BREAK-EVEN AUTOCORRELATIONS

beac=zeros(100,1);
for jj=0:99
	rho_be=jj/100;
	results1=solve_NZLB_dis(NZLB,rho_be,e0,parameter_set,0);
	beac(jj+1,1)=sum(results1(:,7));
end

figure(14)
h1 = plot(linspace(0,0.99,100)',beac(:,1),'--k');
hold on;
h2 = plot(linspace(0,0.99,100)',baseline_loss*ones(100,1),'-k');
legend('loss function value at NZLB=0.02/4 for a given rho','loss function value for ZLB and rho=0.8')
title('Loss equivalence of positive lower bound under lower autocorrelation of shock to natural interest rate (rho) - discretion');
xa_def = [0.5 0.5 0.8 0.8 0.5]; ya_def = [0 0.03 0.03 0 0];
h5 = fill(xa_def,ya_def,[0.9 0.9 0.9], 'LineStyle', 'none');
set(gca, 'Children', [h1 h2 h5])
%axis([0 (max_length-1)  -0.3 0.1]);
saveas(14,'Graphs/14_BE_AC_dis.jpg','jpg');
descr={'rho','loss function value at NZLB=0.02/4 for a given rho','loss function value for ZLB and rho=0.8'};
xlswrite('Graphs/data.xlsx',descr,14,'B1');
xlswrite('Graphs/data.xlsx',[linspace(0,0.99,100)',beac(:,1),baseline_loss*ones(100,1)],14,'B2');


%4a LAYERS OF LOSS wrt. RHO and LB
layersD=zeros(100,100);
rhos=(0:99)/100;
LBs=linspace(-0.02,0.04,100)/4;
for jj=1:100
    rho_now=rhos(jj);
    jj
    for kk=1:100
        LB_now=LBs(kk);
        resultsGER=solve_NZLB_dis(LB_now,rho_now,e0,parameter_set,0);
        layersD(jj,kk)=sum(resultsGER(:,7));
    end
end

descr={'rho\LB (loss under dis)'};
xlswrite('Graphs/data.xlsx',descr,32,'B1');
xlswrite('Graphs/data.xlsx',LBs,32,'C1');
xlswrite('Graphs/data.xlsx',[rhos',layersD],32,'B2');


%5 BEAK-EVEN SHOCK SIZES
bess=zeros(31,1);
for jj=1:31
	e0=-(jj+19)/1000;
	results3=solve_NZLB_dis(NZLB,rho,e0,parameter_set,0);
	bess(jj,1)=sum(results3(:,7));
end

figure(15)
plot(linspace(0.02,0.05,31)',bess(:,1),'--k',...
linspace(0.02,0.05,31)',baseline_loss*ones(31,1),'-k')
legend('loss function value at NZLB=0.02/4 for a given e0','loss function value for ZLB and e0=0.05')
title('Loss equivalence of positive lower bound under lower size of shock to natural interest rate (e0) - discretion');
%axis([0 (max_length-1)  -0.3 0.1]);
saveas(15,'Graphs/15_BE_SS_dis.jpg','jpg');
descr={'rho','loss function value at NZLB=0.02/4 for a given e0','loss function value for ZLB and e0=0.05'};
xlswrite('Graphs/data.xlsx',descr,15,'B1');
xlswrite('Graphs/data.xlsx',[linspace(0.02,0.05,31)',bess(:,1),baseline_loss*ones(31,1)],15,'B2');

%6 SENSITIVITY TABLES
rho_sensit=linspace(0.5,0.9,9)';
nzlb_sensit=linspace(0.001,0.02/4,5)';
e0_sensit=linspace(-0.02,-0.10,9)';
epsilon_sensit=[0.1; 1.1; 2; 3; 5; 10; 100];
potential_gdp_growth_sensit = [0.04; 0.03; 0.02;0.01;0.00];
pi_star_sensit = [(1.02)^(1/4); (1.03)^(1/4); (1.04)^(1/4)];
theta_sensit = linspace(0.4,0.9,11)';
theta_sensit(8)=parameter_set(5);
phi_sensit = [0.1; 0.25; 0.5; 1; 2; 3; 5];
accuracy1=1000;
accuracy2=10000;
filename = 'Tables/sensitivity_dis.xlsx';

%6a: rows - NZLB, columns - baseline rho, content: break-even rho
table1=zeros(size(nzlb_sensit,1),size(rho_sensit,1));
for ii=1:size(rho_sensit,1)
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_dis(0,rho_sensit(ii),e0,parameter_set,0);
        loss_0=sum(results_0(:,7));
        rho_1=rho_sensit(ii);
        results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set,0);
        loss_1=sum(results_1(:,7));
        while (loss_1>=loss_0 && rho_1>=0)
            rho_1=rho_1-1/accuracy1;
            results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set,0);
            loss_1=sum(results_1(:,7));
            if loss_1>=loss_0 && rho_1<0
                rho_1=NaN;
            end
        end
        table1(jj,ii)=rho_1;
    end
end
sensitivity1=[NaN,rho_sensit';nzlb_sensit,table1];
descr={'break-even rho','','baseline rho';'','','',;'PLB','',''};
xlswrite(filename,descr,1,'A1');
xlswrite(filename,sensitivity1,1,'B2');
display('Sensitivity table 1 saved - discretion');

%6b: rows - NZLB, columns - lambda, content: break-even rho
table2=zeros(size(nzlb_sensit,1),size(epsilon_sensit,1));
info_lambda=zeros(1,size(epsilon_sensit,1));
for ii=1:size(epsilon_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,8)=epsilon_sensit(ii,1);
    [~,NKPC]=positive_inf_steady(parameter_set_sensit(1,2),parameter_set_sensit(1,5),parameter_set_sensit(1,6),parameter_set_sensit(1,7),parameter_set_sensit(1,8),parameter_set_sensit(1,1),parameter_set_sensit(1,4)+1);
    info_lambda(1,ii)=NKPC(1,2)/epsilon_sensit(ii,1);
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_dis(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,7));
        rho_1=rho;
        results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
        loss_1=sum(results_1(:,7));
        while (loss_1>=loss_0 && rho_1>=0)
            rho_1=rho_1-1/accuracy1;
            results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
            loss_1=sum(results_1(:,7));
            if loss_1>=loss_0 && rho_1<0
                rho_1=NaN;
            end
        end
        table2(jj,ii)=rho_1;
    end
end
sensitivity2=[NaN,epsilon_sensit';nzlb_sensit,table2];
descr={'','','implied lambda';'','','';'break-even rho','','epsilon';'','','',;'PLB','',''};
xlswrite(filename,descr,2,'A1');
xlswrite(filename,info_lambda,2,'C2');
xlswrite(filename,sensitivity2,2,'B4');
display('Sensitivity table 2 saved - discretion');

%6c: rows - NZLB, columns - baseline e0, content: break-even e0
table3=zeros(size(nzlb_sensit,1),size(e0_sensit,1));
for ii=1:size(e0_sensit,1)
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_dis(0,rho,e0_sensit(ii),parameter_set,0);
        loss_0=sum(results_0(:,7));
        e0_1=e0_sensit(ii);
        results_1=solve_NZLB_dis(nzlb_sensit(jj),rho,e0_1,parameter_set,0);
        loss_1=sum(results_1(:,7));
        while (loss_1>=loss_0 && e0_1<=0)
            e0_1=e0_1+1/accuracy2;
            results_1=solve_NZLB_dis(nzlb_sensit(jj),rho,e0_1,parameter_set,0);
            loss_1=sum(results_1(:,7));
            if loss_1>=loss_0 && e0_1>0
                e0_1=NaN;
            end
        end
        table3(jj,ii)=e0_1;
    end
end
sensitivity3=[NaN,e0_sensit';nzlb_sensit,table3];
descr={'break-even Epsilon1','','baseline Epsilon1';'','','',;'PLB','',''};
xlswrite(filename,descr,3,'A1');
xlswrite(filename,sensitivity3,3,'B2');
display('Sensitivity table 3 saved - discretion');

%6d: rows - NZLB, columns - lambda, content: break-even e0
table4=zeros(size(nzlb_sensit,1),size(epsilon_sensit,1));
for ii=1:size(epsilon_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,8)=epsilon_sensit(ii,1);
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_dis(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,7));
        e0_1=e0;
        results_1=solve_NZLB_dis(nzlb_sensit(jj),rho,e0_1,parameter_set_sensit,0);
        loss_1=sum(results_1(:,7));
        while (loss_1>=loss_0 && e0_1<=0)
            e0_1=e0_1+1/accuracy2;
            results_1=solve_NZLB_dis(nzlb_sensit(jj),rho,e0_1,parameter_set_sensit,0);
            loss_1=sum(results_1(:,7));
            if loss_1>=loss_0 && e0_1>0
                e0_1=NaN;
            end
        end
        table4(jj,ii)=e0_1;
    end
end
sensitivity4=[NaN,epsilon_sensit';nzlb_sensit,table4];
descr={'','','implied lambda';'','','';'break-even e1','','epsilon';'','','',;'PLB','',''};
xlswrite(filename,descr,4,'A1');
xlswrite(filename,info_lambda,4,'C2');
xlswrite(filename,sensitivity4,4,'B4');
display('Sensitivity table 4 saved - discretion');

%6e: rows - NZLB, columns - potential gdp growth, content: break-even rho
table5=zeros(size(nzlb_sensit,1),size(potential_gdp_growth_sensit,1));
for ii=1:size(potential_gdp_growth_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,3)=potential_gdp_growth_sensit(ii,1);
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_dis(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,7));
        rho_1=rho;
        results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
        loss_1=sum(results_1(:,7));
        while (loss_1>=loss_0 && rho_1>=0)
            rho_1=rho_1-1/accuracy1;
            results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
            loss_1=sum(results_1(:,7));
            if loss_1>=loss_0 && rho_1<0
                rho_1=NaN;
            end
        end
        table5(jj,ii)=rho_1;
    end
end
sensitivity5=[NaN,potential_gdp_growth_sensit';nzlb_sensit,table5];
descr={'break-even rho','','potential gdp growth';'','','',;'PLB','',''};
xlswrite(filename,descr,5,'A1');
xlswrite(filename,sensitivity5,5,'B2');
display('Sensitivity table 5 saved - discretion');

%6f: rows - NZLB, columns - pi_star, content: break-even rho
table6=zeros(size(nzlb_sensit,1),size(pi_star_sensit,1));
for ii=1:size(pi_star_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,4)=pi_star_sensit(ii,1)-1;
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_dis(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,7));
        rho_1=rho;
        results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
        loss_1=sum(results_1(:,7));
        while (loss_1>=loss_0 && rho_1>=0)
            rho_1=rho_1-1/accuracy1;
            results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
            loss_1=sum(results_1(:,7));
            if loss_1>=loss_0 && rho_1<0
                rho_1=NaN;
            end
        end
        table6(jj,ii)=rho_1;
    end
end
sensitivity6=[NaN,(((pi_star_sensit).^4)-ones(size(pi_star_sensit,1),size(pi_star_sensit,2)))';nzlb_sensit,table6];
descr={'break-even rho','','pi star';'','','',;'PLB','',''};
xlswrite(filename,descr,6,'A1');
xlswrite(filename,sensitivity6,6,'B2');
display('Sensitivity table 6 saved - discretion');

%6g: rows - NZLB, columns - theta, content: break-even rho
table7=zeros(size(nzlb_sensit,1),size(theta_sensit,1));
for ii=1:size(theta_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,5)=theta_sensit(ii,1);
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_dis(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,7));
        rho_1=rho;
        results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
        loss_1=sum(results_1(:,7));
        while (loss_1>=loss_0 && rho_1>=0)
            rho_1=rho_1-1/accuracy1;
            results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
            loss_1=sum(results_1(:,7));
            if loss_1>=loss_0 && rho_1<0
                rho_1=NaN;
            end
        end
        table7(jj,ii)=rho_1;
    end
end
sensitivity7=[NaN,theta_sensit';nzlb_sensit,table7];
descr={'break-even rho','','theta';'','','',;'PLB','',''};
xlswrite(filename,descr,7,'A1');
xlswrite(filename,sensitivity7,7,'B2');
display('Sensitivity table 7 saved - discretion');

%6h: rows - NZLB, columns - phi, content: break-even rho
table8=zeros(size(nzlb_sensit,1),size(phi_sensit,1));
for ii=1:size(phi_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,7)=phi_sensit(ii,1);
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_dis(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,7));
        rho_1=rho;
        results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
        loss_1=sum(results_1(:,7));
        while (loss_1>=loss_0 && rho_1>=0)
            rho_1=rho_1-1/accuracy1;
            results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
            loss_1=sum(results_1(:,7));
            if loss_1>=loss_0 && rho_1<0
                rho_1=NaN;
            end
        end
        table8(jj,ii)=rho_1;
    end
end
sensitivity8=[NaN,phi_sensit';nzlb_sensit,table8];
descr={'break-even rho','','phi';'','','',;'PLB','',''};
xlswrite(filename,descr,8,'A1');
xlswrite(filename,sensitivity8,8,'B2');
display('Sensitivity table 8 saved - discretion');

%6i: rows - NZLB, columns - baseline rho, content: break-even rho
table9=zeros(size(nzlb_sensit,1),size(rho_sensit,1));
for ii=1:size(rho_sensit,1)
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_com(0,rho_sensit(ii),e0,parameter_set,0);
        loss_0=sum(results_0(:,9));
        rho_1=rho_sensit(ii);
        results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set,0);
        loss_1=sum(results_1(:,7));
        while (loss_1>=loss_0 && rho_1>=0)
            rho_1=rho_1-1/accuracy1;
            results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set,0);
            loss_1=sum(results_1(:,7));
            if loss_1>=loss_0 && rho_1<0
                rho_1=NaN;
            end
        end
        table9(jj,ii)=rho_1;
    end
end
sensitivity9=[NaN,rho_sensit';nzlb_sensit,table9];
descr={'break-even rho vs commitment','','baseline rho';'','','',;'PLB','',''};
xlswrite(filename,descr,9,'A1');
xlswrite(filename,sensitivity9,9,'B2');
display('Sensitivity table 9 saved - discretion');

%6j: rows - NZLB, columns - lambda, content: break-even rho
table10=zeros(size(nzlb_sensit,1),size(epsilon_sensit,1));
info_lambda=zeros(1,size(epsilon_sensit,1));
for ii=1:size(epsilon_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,8)=epsilon_sensit(ii,1);
    [~,NKPC]=positive_inf_steady(parameter_set_sensit(1,2),parameter_set_sensit(1,5),parameter_set_sensit(1,6),parameter_set_sensit(1,7),parameter_set_sensit(1,8),parameter_set_sensit(1,1),parameter_set_sensit(1,4)+1);
    info_lambda(1,ii)=NKPC(1,2)/epsilon_sensit(ii,1);
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_com(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,9));
        rho_1=rho;
        results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
        loss_1=sum(results_1(:,7));
        while (loss_1>=loss_0 && rho_1>=0)
            rho_1=rho_1-1/accuracy1;
            results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
            loss_1=sum(results_1(:,7));
            if loss_1>=loss_0 && rho_1<0
                rho_1=NaN;
            end
        end
        table10(jj,ii)=rho_1;
    end
end
sensitivity10=[NaN,epsilon_sensit';nzlb_sensit,table10];
descr={'','','implied lambda';'','','';'break-even rho vs commitment','','epsilon';'','','',;'PLB','',''};
xlswrite(filename,descr,10,'A1');
xlswrite(filename,info_lambda,10,'C2');
xlswrite(filename,sensitivity10,10,'B4');
display('Sensitivity table 10 saved - discretion');

%6k: rows - NZLB, columns - baseline e0, content: break-even e0
table11=zeros(size(nzlb_sensit,1),size(e0_sensit,1));
for ii=1:size(e0_sensit,1)
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_com(0,rho,e0_sensit(ii),parameter_set,0);
        loss_0=sum(results_0(:,9));
        e0_1=e0_sensit(ii);
        results_1=solve_NZLB_dis(nzlb_sensit(jj),rho,e0_1,parameter_set,0);
        loss_1=sum(results_1(:,7));
        while (loss_1>=loss_0 && e0_1<=0)
            e0_1=e0_1+1/accuracy2;
            results_1=solve_NZLB_dis(nzlb_sensit(jj),rho,e0_1,parameter_set,0);
            loss_1=sum(results_1(:,7));
            if loss_1>=loss_0 && e0_1>0
                e0_1=NaN;
            end
        end
        table11(jj,ii)=e0_1;
    end
end
sensitivity11=[NaN,e0_sensit';nzlb_sensit,table11];
descr={'break-even Epsilon1 vs commitment','','baseline Epsilon1';'','','',;'PLB','',''};
xlswrite(filename,descr,11,'A1');
xlswrite(filename,sensitivity11,11,'B2');
display('Sensitivity table 11 saved - discretion');

%6l: rows - NZLB, columns - lambda, content: break-even e0
table12=zeros(size(nzlb_sensit,1),size(epsilon_sensit,1));
for ii=1:size(epsilon_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,8)=epsilon_sensit(ii,1);
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_com(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,9));
        e0_1=e0;
        results_1=solve_NZLB_dis(nzlb_sensit(jj),rho,e0_1,parameter_set_sensit,0);
        loss_1=sum(results_1(:,7));
        while (loss_1>=loss_0 && e0_1<=0)
            e0_1=e0_1+1/accuracy2;
            results_1=solve_NZLB_dis(nzlb_sensit(jj),rho,e0_1,parameter_set_sensit,0);
            loss_1=sum(results_1(:,7));
            if loss_1>=loss_0 && e0_1>0
                e0_1=NaN;
            end
        end
        table12(jj,ii)=e0_1;
    end
end
sensitivity12=[NaN,epsilon_sensit';nzlb_sensit,table12];
descr={'','','implied lambda';'','','';'break-even e1 vs commitment','','epsilon';'','','',;'PLB','',''};
xlswrite(filename,descr,12,'A1');
xlswrite(filename,info_lambda,12,'C2');
xlswrite(filename,sensitivity12,12,'B4');
display('Sensitivity table 12 saved - discretion');

%6m: rows - NZLB, columns - potential gdp growth, content: break-even rho
table13=zeros(size(nzlb_sensit,1),size(potential_gdp_growth_sensit,1));
for ii=1:size(potential_gdp_growth_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,3)=potential_gdp_growth_sensit(ii,1);
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_com(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,9));
        rho_1=rho;
        results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
        loss_1=sum(results_1(:,7));
        while (loss_1>=loss_0 && rho_1>=0)
            rho_1=rho_1-1/accuracy1;
            results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
            loss_1=sum(results_1(:,7));
            if loss_1>=loss_0 && rho_1<0
                rho_1=NaN;
            end
        end
        table13(jj,ii)=rho_1;
    end
end
sensitivity13=[NaN,potential_gdp_growth_sensit';nzlb_sensit,table13];
descr={'break-even rho vs commitment','','potential gdp growth';'','','',;'PLB','',''};
xlswrite(filename,descr,13,'A1');
xlswrite(filename,sensitivity13,13,'B2');
display('Sensitivity table 13 saved - discretion');

%6n: rows - NZLB, columns - pi_star, content: break-even rho
table14=zeros(size(nzlb_sensit,1),size(pi_star_sensit,1));
for ii=1:size(pi_star_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,4)=pi_star_sensit(ii,1)-1;
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_com(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,9));
        rho_1=rho;
        results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
        loss_1=sum(results_1(:,7));
        while (loss_1>=loss_0 && rho_1>=0)
            rho_1=rho_1-1/accuracy1;
            results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
            loss_1=sum(results_1(:,7));
            if loss_1>=loss_0 && rho_1<0
                rho_1=NaN;
            end
        end
        table14(jj,ii)=rho_1;
    end
end
sensitivity14=[NaN,(((pi_star_sensit).^4)-ones(size(pi_star_sensit,1),size(pi_star_sensit,2)))';nzlb_sensit,table14];
descr={'break-even rho vs commitment','','pi star';'','','',;'PLB','',''};
xlswrite(filename,descr,14,'A1');
xlswrite(filename,sensitivity14,14,'B2');
display('Sensitivity table 14 saved - discretion');

%6o: rows - NZLB, columns - theta, content: break-even rho
table15=zeros(size(nzlb_sensit,1),size(theta_sensit,1));
for ii=1:size(theta_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,5)=theta_sensit(ii,1);
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_com(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,9));
        rho_1=rho;
        results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
        loss_1=sum(results_1(:,7));
        while (loss_1>=loss_0 && rho_1>=0)
            rho_1=rho_1-1/accuracy1;
            results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
            loss_1=sum(results_1(:,7));
            if loss_1>=loss_0 && rho_1<0
                rho_1=NaN;
            end
        end
        table15(jj,ii)=rho_1;
    end
end
sensitivity15=[NaN,theta_sensit';nzlb_sensit,table15];
descr={'break-even rho vs commitment','','theta';'','','',;'PLB','',''};
xlswrite(filename,descr,15,'A1');
xlswrite(filename,sensitivity15,15,'B2');
display('Sensitivity table 15 saved - discretion');

%6p: rows - NZLB, columns - phi, content: break-even rho
table16=zeros(size(nzlb_sensit,1),size(phi_sensit,1));
for ii=1:size(phi_sensit,1)
    parameter_set_sensit=parameter_set;
    parameter_set_sensit(1,7)=phi_sensit(ii,1);
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_com(0,rho,e0,parameter_set_sensit,0);
        loss_0=sum(results_0(:,9));
        rho_1=rho;
        results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
        loss_1=sum(results_1(:,7));
        while (loss_1>=loss_0 && rho_1>=0)
            rho_1=rho_1-1/accuracy1;
            results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0,parameter_set_sensit,0);
            loss_1=sum(results_1(:,7));
            if loss_1>=loss_0 && rho_1<0
                rho_1=NaN;
            end
        end
        table16(jj,ii)=rho_1;
    end
end
sensitivity16=[NaN,phi_sensit';nzlb_sensit,table16];
descr={'break-even rho vs commitment','','phi';'','','',;'PLB','',''};
xlswrite(filename,descr,16,'A1');
xlswrite(filename,sensitivity16,16,'B2');
display('Sensitivity table 16 saved - discretion');

%6r: rows - NZLB, columns - baseline e0, content: break-even e0
table17=zeros(size(nzlb_sensit,1),size(e0_sensit,1));
for ii=1:size(e0_sensit,1)
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_dis(0,rho,e0_sensit(ii),parameter_set,0);
        loss_0=sum(results_0(:,7));
        rho_1=rho;
        results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0_sensit(ii),parameter_set,0);
        loss_1=sum(results_1(:,7));
        while (loss_1>=loss_0 && rho_1>=0)
            rho_1=rho_1-1/accuracy1;
            results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0_sensit(ii),parameter_set,0);
            loss_1=sum(results_1(:,7));
            if loss_1>=loss_0 && rho_1<0
                rho_1=NaN;
            end
        end
        table17(jj,ii)=rho_1;
    end
end
sensitivity17=[NaN,e0_sensit';nzlb_sensit,table17];
descr={'break-even rho','','baseline Epsilon1';'','','',;'PLB','',''};
xlswrite(filename,descr,17,'A1');
xlswrite(filename,sensitivity17,17,'B2');
display('Sensitivity table 17 saved - discretion');

%6r: rows - NZLB, columns - baseline e0, content: break-even e0
table18=zeros(size(nzlb_sensit,1),size(e0_sensit,1));
for ii=1:size(e0_sensit,1)
    for jj=1:size(nzlb_sensit,1)
        results_0=solve_NZLB_com(0,rho,e0_sensit(ii),parameter_set,0);
        loss_0=sum(results_0(:,9));
        rho_1=rho;
        results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0_sensit(ii),parameter_set,0);
        loss_1=sum(results_1(:,7));
        while (loss_1>=loss_0 && rho_1>=0)
            rho_1=rho_1-1/accuracy1;
            results_1=solve_NZLB_dis(nzlb_sensit(jj),rho_1,e0_sensit(ii),parameter_set,0);
            loss_1=sum(results_1(:,7));
            if loss_1>=loss_0 && rho_1<0
                rho_1=NaN;
            end
        end
        table18(jj,ii)=rho_1;
    end
end
sensitivity18=[NaN,e0_sensit';nzlb_sensit,table18];
descr={'break-even rho','','baseline Epsilon1';'','','',;'PLB','',''};
xlswrite(filename,descr,18,'A1');
xlswrite(filename,sensitivity18,18,'B2');
display('Sensitivity table 18 saved - discretion');

%7 RHO/E0 TRADE-OFF UNDER PLB/ZLB
rho_grid=linspace(0.5,0.9,41)';
e0_results=zeros(size(rho_grid,1),2);

for ii=1:size(rho_grid,1)
    e0_seek1=e0;
%     results_1=solve_NZLB_dis(0,rho_grid(ii),e0,parameter_set,0);
%     loss_1=sum(results_1(:,7));
    results_2=solve_NZLB_dis(NZLB,rho_grid(ii),e0,parameter_set,0);
    loss_2=sum(results_2(:,7));
    while (loss_2>baseline_loss)
        e0_seek1=e0_seek1+1/accuracy2;
        results_2=solve_NZLB_dis(NZLB,rho_grid(ii),e0_seek1,parameter_set,0);
        loss_2=sum(results_2(:,7));
    end
    while (loss_2<baseline_loss)
        e0_seek1=e0_seek1-1/accuracy2;
        results_2=solve_NZLB_dis(NZLB,rho_grid(ii),e0_seek1,parameter_set,0);
        loss_2=sum(results_2(:,7));
    end
    e0_seek2=e0;
    while (loss_2>baseline_loss_com)
        e0_seek2=e0_seek2+1/accuracy2;
        results_2=solve_NZLB_dis(NZLB,rho_grid(ii),e0_seek2,parameter_set,0);
        loss_2=sum(results_2(:,7));
    end
    while (loss_2<baseline_loss_com)
        e0_seek2=e0_seek2-1/accuracy2;
        results_2=solve_NZLB_dis(NZLB,rho_grid(ii),e0_seek2,parameter_set,0);
        loss_2=sum(results_2(:,7));
    end
    e0_results(ii,1)=e0_seek1;
    e0_results(ii,2)=e0_seek2;
end

%commented version - with ZLB
% figure(17)
% plot(rho_grid,e0_results(:,1),'--k',...
% rho_grid,e0_results(:,2),':k',...
% rho_grid,e0*ones(size(rho_grid,1),1),'-k')
% xlabel('rho')
% ylabel('e1')
% legend('ZLB','PLB','baseline e1')
% title('Loss equivalence: baseline ZLB scenario vs ZLB and PLB under different rho and e1 -- discretion');
% saveas(17,'Graphs/17_equivalence_dis.jpg','jpg');
% display('Rho/e0 graph created - discretion');

figure(17)
plot(rho_grid,e0_results(:,1),'--k',...
rho_grid,e0*ones(size(rho_grid,1),1),'-k')
xlabel('rho')
ylabel('e1')
legend('PLB','baseline e1','Location','South')
title('Line of equivalent loss under PLB -- discretion');
saveas(17,'Graphs/17_equivalence_dis.jpg','jpg');
display('Rho/e0 graph created - discretion');
descr={'rho','PLB','baseline e1'};
xlswrite('Graphs/data.xlsx',descr,17,'B1');
xlswrite('Graphs/data.xlsx',[rho_grid,e0_results(:,1),e0*ones(size(rho_grid,1),1)],17,'B2');

equiv_dis_plb=e0_results(:,1);
equiv_dis_plb_vsCom=e0_results(:,2);
save('crossgraphs4.mat','equiv_dis_plb','equiv_dis_plb_vsCom');

beac=zeros(99,1);
parameter_set_alt1=[parameter_set(1,1),parameter_set(1,2),0.04,(1.04)^(1/4)-1,0.9,parameter_set(1,6),5,10];
results1z=solve_NZLB_dis(0,rho,e0,parameter_set_alt1,0);
loss1z=sum(results1z(:,7));
% parameter_set_alt2=[parameter_set(1,1),parameter_set(1,2),0.00,(1.00)^(1/4)-1,0.4,parameter_set(1,6),0.1,1.1];
% results2z=solve_NZLB_dis(0,rho,e0,parameter_set_alt2,0);
% loss2z=sum(results2z(:,7));

for jj=0:98
	rho_be=jj/100;
	results1=solve_NZLB_dis(NZLB,rho_be,e0,parameter_set_alt1,0);
	beac(jj+1,1)=sum(results1(:,7));
%     results2=solve_NZLB_dis(NZLB,rho_be,e0,parameter_set_alt2,0);
% 	beac(jj+1,2)=sum(results2(:,7));
end

figure(29)
h1 = plot(linspace(0,0.98,99)',beac(:,1),'--k');
hold on
%h2 = plot(linspace(0,0.98,99)',beac(:,2)/loss2z,'-k');
h2 = plot(linspace(0,0.99,99)',loss1z*ones(99,1),'-k');
legend('PLB under commitment, growth=0.04, inf.target=0.04, theta=0.9, phi=5, epsilon=10','ZLB under commitment, baseline rho and the same parameters');
title('Loss under positive lower bound under different parameters, as a function of rho');
xa_def = [0.5 0.5 0.8 0.8 0.5]; ya_def = [0.0002 0.002 0.002 0.0002 0.0002];
h5 = fill(xa_def,ya_def,[0.9 0.9 0.9], 'LineStyle', 'none');
set(gca, 'Children', [h1 h2 h5])
%axis([0 (max_length-1)  -0.3 0.1]);
saveas(29,'Graphs/29_BE_AC_dis.jpg','jpg');
descr={'rho','loss function value set 1, discretion','loss function value set 2, discretion'};
xlswrite('Graphs/data.xlsx',descr,29,'B1');
xlswrite('Graphs/data.xlsx',[linspace(0,0.98,99)',beac(:,1),loss1z*ones(99,1)],29,'B2');
