function [results]=solve_NZLB_EW_com(NZLB,e0,k,tau,parameter_set,alpha_cond)

% e0 - initial magnitude of the shock
% NZLB - where to stop cutting nominal interest rate
% k - how many periods since the shock dies down to the moment when the LB stops to bind
% tau - when the shock dies down

%%% showplot - 0 if plots to be shown, 1 if not
%%% baseline_loss: number for the purpose of presentation, useless when showplot=0

%1 DEFINE DEEP PARAMETERS

%%%horizon_max = 30; %maximum number of periods in consideration (Phase 1)
sigma=parameter_set(1,1);
beta=parameter_set(1,2);
potential_gdp_growth=parameter_set(1,3);
pi_star=parameter_set(1,4);
theta=parameter_set(1,5);
one_minus_alpha=parameter_set(1,6);
phi=parameter_set(1,7);
epsilon=parameter_set(1,8);

[NKPC_PI,~]=positive_inf_steady(beta,theta,one_minus_alpha,phi,epsilon,sigma,pi_star+1);
beta1=NKPC_PI(1,1);
beta2=NKPC_PI(1,2);
kappa1=NKPC_PI(1,3);
kappa2=NKPC_PI(1,4);
aux_const=((pi_star+1)^(epsilon-1))*((pi_star+1)^(1-epsilon)-theta)^(-epsilon/(1-epsilon))*(1-theta)^(1/(1-epsilon));
lambda=((1-beta*theta)*aux_const^2)/(1-theta-aux_const^2)*(phi+sigma)/epsilon;

AA=[beta2 beta1 kappa1*kappa2/lambda 1/lambda*((kappa1^2)+(kappa2^2)/beta) ; 0 1 1 -beta1/beta; 0 1 0 0 ; 0 0 0 1 ];
BB=[0 1 0 -kappa1*kappa2/lambda/beta ; 0 0 0  (1/(beta^2))*beta2; 1 0 0 0 ; 0 0 1 0 ];
MM=solve_model(AA,BB,2);
nat_int_rate=sigma*potential_gdp_growth/4+(1-beta)*beta;
gamma1=MM(1,1);
gamma2=MM(1,2);

%2 phases 2 and 3

Omega=zeros(3,3,k+1);
Lambda=zeros(3,3,k+1);
Phi=zeros(3,1,k+1);
Theta=zeros(3,1,k+1);
%the first entry in 3rd dimension are matrices in phase 3;
%the following go backwards through period 2 until the border with period 1 (tau)

%phase 3

Omega(:,:,1)=[0,0,0; 0,gamma1,gamma2; 0,1,0];
Lambda(:,:,1)=[1/(beta*lambda),kappa2/(beta*lambda)+kappa1*gamma1/lambda,kappa1*gamma2/lambda;...
                1/(beta*sigma),-gamma1+beta1/beta,-gamma2+beta2/beta^2;...
                0,(beta1/beta-gamma1)*gamma1+beta2/(beta^2)-gamma2,(beta1/beta-gamma1)*gamma2];
            
%phase 2
            
A2=[1/beta kappa2/beta 0 0 0 0;...
    1/(beta*sigma) beta1/beta beta2/(beta^2) 0 0 0;...
    0 1 0 0 0 0;...
    0 0 0 kappa2 beta1 beta2;...
    0 0 0 1 1/sigma 0;...
    0 0 0 0 1 0];

A1=[1 -kappa1 0 lambda 0 0;...
    0 1 0 0 1 0;...
    0 0 1 0 0 0;...
    0 0 0 -kappa1 1 0;...
    0 0 0 1 0 0;...
    0 0 0 0 0 1];
    
A3=[0; 0; 0; 0; (-NZLB+pi_star+nat_int_rate)/sigma; 0];

B1=A1\A2;
B2=A1\A3;

A=B1(1:3,1:3);
B=B1(1:3,4:6);
C=B1(4:6,1:3);
D=B1(4:6,4:6);
M=B2(1:3,1);
V=B2(4:6,1);

for jj=2:(k+1)
    Omega(:,:,jj)=(eye(3)-B*Lambda(:,:,jj-1))\A;
    Lambda(:,:,jj)=C+D*Lambda(:,:,jj-1)*Omega(:,:,jj);
    Phi(:,:,jj)=(eye(3)-B*Lambda(:,:,jj-1))\(B*Theta(:,:,jj-1)+M);
    Theta(:,:,jj)=D*Lambda(:,:,jj-1)*Phi(:,:,jj)+D*Theta(:,:,jj-1)+V;
end

%phase 1

n=50;
%alpha_cond=0.1;
alpha=ones(n,1)-(ones(n,1)*(1-alpha_cond)).^(linspace(0,n-1,n)');
alpha(n-1,1)=1;
alpha(n,1)=1;
% alpha_bis=alpha(2:end)-alpha(1:end-1);
% alpha_c=zeros(n,1);
% for jj=1:n-2
%     alpha_c(jj,1)=alpha_bis(jj,1)/sum(alpha_bis(jj:end,1),1);
% end
% alpha=alpha_c;

A1=zeros(6,6,n-1);
A2=zeros(6,6,n-1);
A3=zeros(6,1,n-1);
B1=zeros(6,6,n-1);
B2=zeros(6,1,n-1);

A=zeros(3,3,n-1);
B=zeros(3,3,n-1);
C=zeros(3,3,n-1);
D=zeros(3,3,n-1);
M=zeros(3,1,n-1);
V=zeros(3,1,n-1);

for jj=1:(n-2)
    A2(:,:,jj)=[1/beta kappa2/beta 0 0 0 0;...
        1/(beta*sigma) beta1/beta beta2/(beta^2) 0 0 0;...
        0 1 0 0 0 0;...
        0 beta1*alpha(jj+1,1)*Lambda(2,3,k+1)+beta2*alpha(jj+2,1)*(Lambda(2,1,k)*Omega(1,3,k+1)+Lambda(2,2,k)+Omega(2,3,k+1))+kappa2*alpha(jj+1,1)*Lambda(1,3,k+1) 0 kappa2*(1-alpha(jj+1,1)) beta1*(1-alpha(jj+1,1)) beta2*(1-alpha(jj+2,1));...
        0 alpha(jj+1,1)*Lambda(1,3,k+1)+1/sigma*alpha(jj+1,1)*Lambda(2,3,k+1) 0 (1-alpha(jj+1,1)) 1/sigma*(1-alpha(jj+1,1)) 0;...
        0 0 0 0 1 0];

    A1(:,:,jj)=[1 -kappa1 0 lambda 0 0;...
        0 1 0 0 1 0;...
        0 0 1 0 0 0;...
        -beta1*alpha(jj+1,1)*Lambda(2,1,k+1)-beta2*alpha(jj+2,1)*(Lambda(2,1,k)*Omega(1,1,k+1)+Lambda(2,2,k)*Omega(2,1,k+1))-kappa2*alpha(jj+1,1)*Lambda(1,1,k+1) -beta1*alpha(jj+1,1)*Lambda(2,2,k+1)-beta2*alpha(jj+2,1)*(Lambda(2,1,k)*Omega(1,2,k+1)+Lambda(2,2,k)*Omega(2,2,k+1)+Lambda(2,3,k))-kappa2*alpha(jj+1,1)*Lambda(1,2,k+1) 0 -kappa1 1 0;...
        -Lambda(1,1,k+1)*alpha(jj+1,1)-alpha(jj+1,1)/sigma*Lambda(2,1,k+1) -Lambda(1,2,k+1)*alpha(jj+1,1)-alpha(jj+1,1)/sigma*Lambda(2,2,k+1) 0 1 0 0;...
        0 0 0 0 0 1];

    A3(:,:,jj)=[0; 0; 0; beta2*alpha(jj+2,1)*Lambda(2,1,k)*(Phi(1,1,k+1)+Phi(2,1,k+1))+beta1*alpha(jj+1,1)*Theta(2,1,k+1)+beta1*alpha(jj+2,1)*Theta(2,1,k)+kappa2*alpha(jj+1,1)*Theta(1,1,k+1); (-NZLB+pi_star+nat_int_rate+e0)/sigma+alpha(jj+1,1)*Theta(1,1,k+1)+alpha(jj+1,1)/sigma*Theta(2,1,k+1); 0];
    
    B1(:,:,jj)=A1(:,:,jj)\A2(:,:,jj);
    B2(:,:,jj)=A1(:,:,jj)\A3(:,:,jj);
    
    A(:,:,jj)=B1(1:3,1:3,jj);
    B(:,:,jj)=B1(1:3,4:6,jj);
    C(:,:,jj)=B1(4:6,1:3,jj);
    D(:,:,jj)=B1(4:6,4:6,jj);
    M(:,:,jj)=B2(1:3,1,jj);
    V(:,:,jj)=B2(4:6,1,jj);
end

Omega1=zeros(3,3,n-2);
Lambda1=zeros(3,3,n-2);
Phi1=zeros(3,1,n-2);
Theta1=zeros(3,1,n-2);

Omega1(:,:,n-2)=A(:,:,n-2);
Phi1(:,:,n-2)=M(:,:,n-2);
Lambda1(:,:,n-2)=C(:,:,n-2);
Theta1(:,:,n-2)=V(:,:,n-2);

for jj=3:(n-1)
    Omega1(:,:,n-jj)=(eye(3)-B(:,:,n-jj)*Lambda1(:,:,n-jj+1))\A(:,:,n-jj);
    Lambda1(:,:,n-jj)=C(:,:,n-jj)+D(:,:,n-jj)*Lambda1(:,:,n-jj+1)*Omega1(:,:,n-jj);
    Phi1(:,:,n-jj)=(eye(3)-B(:,:,n-jj)*Lambda1(:,:,n-jj+1))\(B(:,:,n-jj)*Theta1(:,:,n-jj+1)+M(:,:,n-jj));
    Theta1(:,:,n-jj)=D(:,:,n-jj)*Lambda1(:,:,n-jj+1)*Phi1(:,:,n-jj)+D(:,:,n-jj)*Theta1(:,:,n-jj+1)+V(:,:,n-jj);
end


% 
% %3 LOOP TO FIND THE TIME OF LB BINDING AND SIMULATE UNTIL T+2
% 
% %this loop finds the number of periods when lower bound binds by
% %decrementing the assumed period until PHI1 is no more positive
% 
% for jj=1:horizon_max;
%     
% 	%3a DECREMENT jjj
% 	T=horizon_max+1-jj;
%    
	%3b GENERATE THE SHOCK VECTOR
	shock=zeros(2*n,1);
	shock(1:(tau-1),1)=e0*ones(tau-1,1);

    %3d GENERATE THE RESULT CONTAINERS
    
    resP=zeros(2*n+1,3);
    resZ=zeros(2*n+1,3);
    
    for jj=1:(n-2)
        resP(jj+1,:)=(Omega1(:,:,jj)*resP(jj,:)'+Phi1(:,:,jj))';
        resZ(jj+1,:)=(Lambda1(:,:,jj)*resP(jj,:)'+Theta1(:,:,jj))';
    end
    for jj=1:(k+1)
        resP(tau+jj,:)=(Omega(:,:,k+2-jj)*resP(tau+jj-1,:)'+Phi(:,:,k+2-jj))';
        resZ(tau+jj,:)=(Lambda(:,:,k+2-jj)*resP(tau+jj-1,:)'+Theta(:,:,k+2-jj))';        
    end
    for jj=(tau+k+2):(2*n+1)
        resP(jj,:)=(Omega(:,:,1)*resP(jj-1,:)')';
        resZ(jj,:)=(Lambda(:,:,1)*resP(jj-1,:)')';        
    end
        
	Y=resZ(:,1);	%output gap
	PI=resZ(:,2);   %inflation
	PHI1=resP(:,1);  %LM 1
	PHI2=resP(:,2);	%LM 2
    
    PI=PI+pi_star*ones(size(PI,1),1);
% 
% %5 FILL IN THE REST OF THE CONTAINERS

%natural interest rate
RN=nat_int_rate*ones(2*n+1,1);
RN(2:(2*n+1),1)=RN(2:(2*n+1),1)+shock;

%nominal interest rate
NIR=zeros(2*n+1,1);
NIR(1,1)=nat_int_rate+pi_star;
NIR(2:(tau+k),1)=ones(tau+k-1,1)*NZLB;
for ii=(tau+k+1):(2*n);
   NIR(ii,1)=(Y(ii+1,1)-Y(ii,1))*sigma+RN(ii,1)+PI(ii+1,1);
end;
NIR(2*n+1,1)=NaN;

%real interest rate
RIR=zeros(2*n+1,1);
RIR(1,1)=NIR(1,1)-PI(1,1);
for ii=2:(2*n);
   RIR(ii,1)=NIR(ii,1)-PI(ii+1,1);
end;
RIR(2*n+1,1)=NaN;


 
%5 SUMMARIZE AND EVALUATE

discount=ones(size(Y,1),1);
for ii=3:size(Y,1)
    discount(ii,1)=beta*discount(ii-1,1);
end
loss = discount.*((Y.^2)*lambda+(PI-pi_star*ones(size(PI,1),1)).^2);
results = [linspace(0,2*n,2*n+1)' Y PI NIR RIR RN PHI1 PHI2 loss];

% 
% %6 DISPLAY THE RESULTS
% 
% if showplot==1
% 
% 	annot_text_1=['Period 0: steady state' 10 'Period 1: shock occurs' 10 'Period ' num2str(T) ': lower bound no more binding'];
% 	annot_text_2=['Period 0: steady state' 10 'Period 1: shock occurs' 10 'Period ' num2str(T) ': lower bound no more binding'];
% 
% 	figure(1)
% 	plot(0:3*T,NIR(:,1),'-k',0:3*T,RN(:,1),':k',0:3*T,RIR(:,1),'--k',0:3*T,PI(:,1),'-.k')
% 	legend('nominal interest rate','natural interest rate','real interest rate (ex ante)','inflation rate')
% 	title('Interest rates and inflation - commitment')
% 	axis([0 3*T -0.05 0.05])
% 	text(10,-0.02,annot_text_1);
% 	saveas(1,'Graphs/1_IRF_rates_pi_com.jpg','jpg');
%     descr={'nominal interest rate','natural interest rate','real interest rate (ex ante)','inflation rate'};
%     xlswrite('Graphs/data.xlsx',descr,1,'B1');
%     xlswrite('Graphs/data.xlsx',[NIR(:,1),RN(:,1),RIR(:,1),PI(:,1)],1,'B2');
%     %display(annot_text_1);
% 
% 	figure(2)
% 	plot(0:3*T,Y,'-k',0:3*T,PHI1*100,'--k',0:3*T,PHI2,':k')
% 	title('Output gap and Lagrange multipliers - commitment')
% 	legend('output gap','Lagrange multiplier 1 (*10^2)','Lagrange multiplier 2');
% 	%axis([0 3*T -0.4 0.3])
% 	text(8,-0.15,annot_text_2);
% 	saveas(2,'Graphs/2_IRF_output_phi_pi_com.jpg','jpg');
%     descr={'output gap','Lagrange multiplier 1 (*10^2)','Lagrange multiplier 2'};
%     xlswrite('Graphs/data.xlsx',descr,2,'B1');
%     xlswrite('Graphs/data.xlsx',[Y,PHI1*100,PHI2],2,'B2');
% 
%     display(['Commitment: loss function value: ' num2str(sum(loss)) ' as compared to ' num2str(baseline_loss) ' under ZLB']);
%     
% end
% 
% 
