function [results]=solve_NZLB_EW_dis(NZLB,e0,tau,parameter_set,alpha_cond)

% e0 - initial magnitude of the shock
% NZLB - where to stop cutting nominal interest rate
% k - how many periods since the shock dies down to the moment when the LB stops to bind
% tau - when the shock dies down

%%% showplot - 0 if plots to be shown, 1 if not
%%% baseline_loss: number for the purpose of presentation, useless when showplot=0

%1 DEFINE DEEP PARAMETERS

%%%horizon_max = 30; %maximum number of periods in consideration (Phase 1)
sigma=parameter_set(1,1);
beta=parameter_set(1,2);
potential_gdp_growth=parameter_set(1,3);
pi_star=parameter_set(1,4);
theta=parameter_set(1,5);
one_minus_alpha=parameter_set(1,6);
phi=parameter_set(1,7);
epsilon=parameter_set(1,8);

[NKPC_PI,~]=positive_inf_steady(beta,theta,one_minus_alpha,phi,epsilon,sigma,pi_star+1);
beta1=NKPC_PI(1,1);
beta2=NKPC_PI(1,2);
kappa1=NKPC_PI(1,3);
kappa2=NKPC_PI(1,4);
aux_const=((pi_star+1)^(epsilon-1))*((pi_star+1)^(1-epsilon)-theta)^(-epsilon/(1-epsilon))*(1-theta)^(1/(1-epsilon));
lambda=((1-beta*theta)*aux_const^2)/(1-theta-aux_const^2)*(phi+sigma)/epsilon;

nat_int_rate=sigma*potential_gdp_growth/4+(1-beta)*beta;

%phase 1

n=50;
alpha=ones(n,1)-(ones(n,1)*(1-alpha_cond)).^(linspace(0,n-1,n)');
alpha(n-1,1)=1;
alpha(n,1)=1;

A1=zeros(3,3,n-1);
A2=zeros(3,3,n-1);
A3=zeros(3,1,n-1);
B1=zeros(3,3,n-1);
B2=zeros(3,1,n-1);

for jj=1:(n-2)
    A2(:,:,jj)=[kappa2*(1-alpha(jj+1,1)) beta1*(1-alpha(jj+1,1)) beta2*(1-alpha(jj+2,1));...
        (1-alpha(jj+1,1)) 1/sigma*(1-alpha(jj+1,1)) 0;...
        0 1 0];

    A1(:,:,jj)=[-kappa1 1 0;...
        1 0 0;...
        0 0 1];

    A3(:,:,jj)=[0; (-NZLB+pi_star+nat_int_rate+e0)/sigma; 0];
    
    B1(:,:,jj)=A1(:,:,jj)\A2(:,:,jj);
    B2(:,:,jj)=A1(:,:,jj)\A3(:,:,jj);
    
end

    
	%3b GENERATE THE SHOCK VECTOR
	shock=zeros(2*n,1);
	shock(1:(tau-1),1)=e0*ones(tau-1,1);

    %3d GENERATE THE RESULT CONTAINERS
    
    resZ=zeros(2*n+1,3);
    
    for jj=1:(n-3)
        resZ(n-(jj+1),:)=(B1(:,:,n-(jj+2))*resZ(n-jj,:)'+B2(:,:,n-(jj+2)))';
    end
    eve_expected_inflation=(1-alpha(tau+1-1))*resZ(tau+1,2);
    for jj=(tau+1):(n-2)
        resZ(jj,:)=zeros(1,3);        
    end
        
	Y=resZ(:,1);	%output gap
	PI=resZ(:,2);   %inflation
    
    PI=PI+pi_star*ones(size(PI,1),1);
 
% %5 FILL IN THE REST OF THE CONTAINERS

%natural interest rate
RN=nat_int_rate*ones(2*n+1,1);
RN(2:(2*n+1),1)=RN(2:(2*n+1),1)+shock;

%nominal interest rate
NIR=zeros(2*n+1,1);
NIR(1,1)=nat_int_rate+pi_star;
NIR(2:(tau),1)=ones(tau-1,1)*NZLB;
for ii=(tau+1):(2*n);
   NIR(ii,1)=(Y(ii+1,1)-Y(ii,1))*sigma+RN(ii,1)+PI(ii+1,1);
end;
NIR(2*n+1,1)=NaN;

%real interest rate
RIR=zeros(2*n+1,1);
RIR(1,1)=NIR(1,1)-PI(1,1);
for ii=2:(2*n);
   RIR(ii,1)=NIR(ii,1)-PI(ii+1,1);
end;
RIR(2*n+1,1)=NaN;
RIR(tau,1)=NIR(tau,1)-eve_expected_inflation;


 
%5 SUMMARIZE AND EVALUATE

discount=ones(size(Y,1),1);
for ii=3:size(Y,1)
    discount(ii,1)=beta*discount(ii-1,1);
end
loss = discount.*((Y.^2)*lambda+(PI-pi_star*ones(size(PI,1),1)).^2);
results = [linspace(0,2*n,2*n+1)' Y PI NIR RIR RN loss];

% 
% %6 DISPLAY THE RESULTS
% 
% if showplot==1
% 
% 	annot_text_1=['Period 0: steady state' 10 'Period 1: shock occurs' 10 'Period ' num2str(T) ': lower bound no more binding'];
% 	annot_text_2=['Period 0: steady state' 10 'Period 1: shock occurs' 10 'Period ' num2str(T) ': lower bound no more binding'];
% 
% 	figure(1)
% 	plot(0:3*T,NIR(:,1),'-k',0:3*T,RN(:,1),':k',0:3*T,RIR(:,1),'--k',0:3*T,PI(:,1),'-.k')
% 	legend('nominal interest rate','natural interest rate','real interest rate (ex ante)','inflation rate')
% 	title('Interest rates and inflation - commitment')
% 	axis([0 3*T -0.05 0.05])
% 	text(10,-0.02,annot_text_1);
% 	saveas(1,'Graphs/1_IRF_rates_pi_com.jpg','jpg');
%     descr={'nominal interest rate','natural interest rate','real interest rate (ex ante)','inflation rate'};
%     xlswrite('Graphs/data.xlsx',descr,1,'B1');
%     xlswrite('Graphs/data.xlsx',[NIR(:,1),RN(:,1),RIR(:,1),PI(:,1)],1,'B2');
%     %display(annot_text_1);
% 
% 	figure(2)
% 	plot(0:3*T,Y,'-k',0:3*T,PHI1*100,'--k',0:3*T,PHI2,':k')
% 	title('Output gap and Lagrange multipliers - commitment')
% 	legend('output gap','Lagrange multiplier 1 (*10^2)','Lagrange multiplier 2');
% 	%axis([0 3*T -0.4 0.3])
% 	text(8,-0.15,annot_text_2);
% 	saveas(2,'Graphs/2_IRF_output_phi_pi_com.jpg','jpg');
%     descr={'output gap','Lagrange multiplier 1 (*10^2)','Lagrange multiplier 2'};
%     xlswrite('Graphs/data.xlsx',descr,2,'B1');
%     xlswrite('Graphs/data.xlsx',[Y,PHI1*100,PHI2],2,'B2');
% 
%     display(['Commitment: loss function value: ' num2str(sum(loss)) ' as compared to ' num2str(baseline_loss) ' under ZLB']);
%     
% end
% 
% 
