function [results]=solve_NZLB_com(NZLB,rho,e0,parameter_set,showplot,baseline_loss)

% rho - serial correlation of the natural interest rate shock e0
% e0 - initial magnitude of the shock
% NZLB - where to stop cutting nominal interest rate
% showplot - 0 if plots to be shown, 1 if not
% baseline_loss: number for the purpose of presentation, useless when showplot=0

%1 DEFINE DEEP PARAMETERS

horizon_max = 30; %maximum number of periods in consideration (Phase 1)
sigma=parameter_set(1,1);
beta=parameter_set(1,2);
potential_gdp_growth=parameter_set(1,3);
pi_star=parameter_set(1,4);
theta=parameter_set(1,5);
one_minus_alpha=parameter_set(1,6);
phi=parameter_set(1,7);
epsilon=parameter_set(1,8);

[NKPC_PI,~]=positive_inf_steady(beta,theta,one_minus_alpha,phi,epsilon,sigma,pi_star+1);
beta1=NKPC_PI(1,1);
beta2=NKPC_PI(1,2);
kappa1=NKPC_PI(1,3);
kappa2=NKPC_PI(1,4);
aux_const=((pi_star+1)^(epsilon-1))*((pi_star+1)^(1-epsilon)-theta)^(-epsilon/(1-epsilon))*(1-theta)^(1/(1-epsilon));
lambda = ((1-beta*theta)*aux_const^2)/(1-theta-aux_const^2)*(phi+sigma)/epsilon;

%2 COMPUTE SOME REDUCED-FORM PARAMETERS

nat_int_rate=sigma*potential_gdp_growth/4+(1-beta)*beta;

A=[beta2 beta1 kappa1*kappa2/lambda 1/lambda*((kappa1^2)+(kappa2^2)/beta) ; 0 1 1 -beta1/beta; 0 1 0 0 ; 0 0 0 1 ];
B=[0 1 0 -kappa1*kappa2/lambda/beta ; 0 0 0  (1/(beta^2))*beta2; 1 0 0 0 ; 0 0 1 0 ];
[M]=solve_model(A,B,2); 
CC = [-M(1,1)+beta1/beta -M(1,2)+beta2/(beta^2); M(1,1) M(1,2)]; %backward solution for periods tt+2 and later

S1=[1 0 1;0 lambda -kappa1;1 -kappa1 0];
S2=[0 0 0;0 0 0;beta2 beta1 kappa2];
S3=[beta1/beta beta2/(beta^2); kappa2/beta 0; 0 0];
S5=[(beta*sigma)^(-1); beta^(-1); 0];
T1=S1\S2;
T2=S1\S3;
T3=S1\S5;

aux1=-1;
aux2=-1/sigma;
aux3=-kappa1;
aux4=-kappa2;
aux5=-beta1;
aux6=-beta2;
aux7=-1/beta;
aux8=-1/beta*kappa2;
aux9=-1/(beta*sigma);
aux10=-beta2/(beta^2);
aux11=-beta1/beta;

%3 LOOP TO FIND THE TIME OF LB BINDING AND SIMULATE UNTIL T+2

%this loop finds the number of periods when lower bound binds by
%decrementing the assumed period until PHI1 is no more positive

for jj=1:horizon_max;
    
	%3a DECREMENT jjj
	T=horizon_max+1-jj;
   
	%3b GENERATE THE SHOCK VECTOR
	shock=zeros(3*T,1);
	shock(1,1)=e0;
	shock(1,1)=shock(1,1)+nat_int_rate;
	for ii=1:3*T-1;
		shock(ii+1,1)=rho*(shock(ii,1)-nat_int_rate)+nat_int_rate;
	end;
  
    %3c SOLVE FOR PERIODS 1,...,T,T+1,T+2
	nn=4*T+7;
	ENDO=zeros(nn,nn);

	%IS curve
    for ii=1:T-1;
	   ENDO(ii,ii)=1;
	   ENDO(ii,ii+1)=aux1;
	   ENDO(ii,ii+T+2)=aux2;
    end;

    %Phillips curve
	for ii=T:2*T-2;
	   ENDO(ii,ii-T+1)=aux3;
       ENDO(ii,ii-T+2)=aux4;
	   ENDO(ii,ii-T+2+T)=1;
	   ENDO(ii,ii-T+2+T+1)=aux5;
       ENDO(ii,ii-T+2+T+2)=aux6;
	end;

    %Lagrange 1
	for ii=2*T-1:3*T-3;
	   ENDO(ii,ii-2*T+2)=lambda;
	   ENDO(ii,ii-2*T+4+2*T)=aux7;
	   ENDO(ii,ii-2*T+4+2*T+1)=1;
	   ENDO(ii,ii-2*T+5+3*T+2)=aux8;
       ENDO(ii,ii-2*T+5+3*T+3)=aux3;
	end;

    %Lagrange 2
	for ii=3*T-2:4*T-4;
	   ENDO(ii,ii-3*T+4+T)=1;
	   ENDO(ii,ii-3*T+5+2*T)=aux9;
	   ENDO(ii,ii-3*T+6+3*T+1)=aux10;
	   ENDO(ii,ii-3*T+6+3*T+1+1)=aux11;
       ENDO(ii,ii-3*T+6+3*T+1+2)=1;
	end;

    %Initial conditions for LM1 and LM2
	ENDO(4*T-3,2*T+3)=1;
	ENDO(4*T-2,3*T+1+4)=1;
    ENDO(4*T-1,3*T+1+5)=1;

    %Solution for T+2 (pi, y and phi2)
    ENDO(4*T,2*T+2)=-1;%pi
    ENDO(4*T,4*T+7)=T1(1,1)*(CC(1,1)*CC(2,1)+CC(1,2))+T1(1,2)*CC(1,1)+T1(1,3)*(kappa1/lambda*CC(2,1)+kappa2/lambda/beta);%od phi2
    ENDO(4*T,4*T+6)=T1(1,1)*CC(1,1)*CC(2,2)+T1(1,2)*CC(1,2)+T1(1,3)/lambda*kappa1*CC(2,2)+T2(1,1);%od phi2(-1)
    ENDO(4*T,4*T+5)=T2(1,2);% phi2(-2)
    
    ENDO(4*T+1,T+1)=-1;%y
    ENDO(4*T+1,4*T+7)=T1(2,1)*(CC(1,1)*CC(2,1)+CC(1,2))+T1(2,2)*CC(1,1)+T1(2,3)*(kappa1/lambda*CC(2,1)+kappa2/lambda/beta);%od phi2
    ENDO(4*T+1,4*T+6)=T1(2,1)*CC(1,1)*CC(2,2)+T1(2,2)*CC(1,2)+T1(2,3)/lambda*kappa1*CC(2,2)+T2(2,1);%od phi2(-1)
    ENDO(4*T+1,4*T+5)=T2(2,2);% phi2(-2)
    
    ENDO(4*T+2,4*T+7)=T1(3,1)*(CC(1,1)*CC(2,1)+CC(1,2))+T1(3,2)*CC(1,1)+T1(3,3)*(kappa1/lambda*CC(2,1)+kappa2/lambda/beta)-1;%phi2
    ENDO(4*T+2,4*T+6)=T1(3,1)*CC(1,1)*CC(2,2)+T1(3,2)*CC(1,2)+T1(3,3)/lambda*kappa1*CC(2,2)+T2(3,1);
    ENDO(4*T+2,4*T+5)=T2(3,2);
    
    %Solution for T+1 (pi, y and phi2)
    ENDO(4*T+5,2*T+1)=-1;%pi
    ENDO(4*T+5,4*T+7)=T1(1,1)*CC(1,1);
    ENDO(4*T+5,4*T+6)=T1(1,1)*CC(1,2);
    ENDO(4*T+5,4*T+5)=T2(1,1);
    ENDO(4*T+5,4*T+4)=T2(1,2);
    ENDO(4*T+5,2*T+2)=T1(1,2);%pi(+1)
    ENDO(4*T+5,T+1)=T1(1,3);%y(+1)
    ENDO(4*T+5,3*T+2)=T3(1,1);%phi1(-1)
    
    ENDO(4*T+6,T)=-1;%y
    ENDO(4*T+6,4*T+7)=T1(2,1)*CC(1,1);
    ENDO(4*T+6,4*T+6)=T1(2,1)*CC(1,2);
    ENDO(4*T+6,4*T+5)=T2(2,1);
    ENDO(4*T+6,4*T+4)=T2(2,2);
    ENDO(4*T+6,2*T+2)=T1(2,2);
    ENDO(4*T+6,T+1)=T1(2,3);
    ENDO(4*T+6,3*T+2)=T3(2,1);
    
    ENDO(4*T+7,4*T+7)=T1(3,1)*CC(1,1)-1;%phi2
    ENDO(4*T+7,4*T+6)=T1(3,1)*CC(1,2);
    ENDO(4*T+7,4*T+5)=T2(3,1);
    ENDO(4*T+7,4*T+4)=T2(3,2);
    ENDO(4*T+7,2*T+2)=T1(3,2);
    ENDO(4*T+7,T+1)=T1(3,3);
    ENDO(4*T+7,3*T+2)=T3(3,1);
    
    %Terminal conditions on PHI1
	ENDO(4*T+3,3*T+3)=1;
    ENDO(4*T+4,3*T+4)=1;
	
    %exogenous side
	EXO=zeros(nn,1);
	for ii=1:T-1;
	   EXO(ii,1)=-aux2*(shock(ii,1)+pi_star);
	end;
	EXO(1:T-1,1) = EXO(1:T-1,1) + NZLB*(aux2)*ones(T-1,1);

	SOLVED=ENDO\EXO;

	%3d GENERATE THE RESULT CONTAINERS

	Y=zeros(3*T+1,1);	%output gap
	PI=zeros(3*T+1,1);  %inflation
	PHI1=zeros(3*T+1,1);  %LM 1
	PHI2=zeros(3*T+1,1);	%LM 2

	for ii=2:T+2;
	   Y(ii,1)=SOLVED(ii-1,1);
	end;

	for ii=2:T+2;
	   PI(ii,1)=SOLVED(ii+T,1);
	end;

	for ii=1:T+2;
	   PHI1(ii,1)=SOLVED(ii+2*T+2,1);
	end;

	for ii=1:T+2;
	   PHI2(ii,1)=SOLVED(ii+3*T+5,1);
	end;

	%3e VERIFY THE TIMING OF LB BINDING
    phi1_history_nonnegative=1;
    for ii=1:(T-2)
        if PHI1(T-ii,1)<0
            phi1_history_nonnegative=0;
        end
    end
    %display([num2str(jj),' ',num2str(T),' ',num2str(phi1_history_nonnegative),' ',num2str(PHI1(T,1))]);
	if PHI1(T,1)>0 && phi1_history_nonnegative==1;
	   break;
	end;

end;

%4 SIMULATE AFTER T+2

for ii=2:2*T;
   PHI1(T+1+ii,1)=0;
   PHI2(T+1+ii,1)=CC(2,1)*PHI2(T+ii,1)+CC(2,2)*PHI2(T-1+ii,1);
end;

for ii=2:2*T;
   PI(T+1+ii,1)=CC(1,1)*PHI2(T+ii,1)+CC(1,2)*PHI2(T-1+ii,1);
   Y(T+1+ii,1)=kappa2/beta/lambda*PHI2(T+ii,1)+kappa1/lambda*PHI2(T+1+ii,1);
end;

PI=PI+pi_star*ones(size(PI,1),1);

%5 FILL IN THE REST OF THE CONTAINERS

%nominal interest rate
NIR=zeros(3*T+1,1);
NIR(1,1)=nat_int_rate+pi_star;
NIR(2:T,1)=ones(T-1,1)*NZLB;
for ii=T+1:3*T;
   NIR(ii,1)=(Y(ii+1,1)-Y(ii,1))*sigma+shock(ii,1)+PI(ii+1,1);
end;
NIR(3*T+1,1)=NaN;

%real interest rate
RIR=zeros(3*T+1,1);
RIR(1,1)=NIR(1,1)-PI(1,1);
for ii=2:3*T;
   RIR(ii,1)=NIR(ii,1)-PI(ii+1,1);
end;
RIR(3*T+1,1)=NaN;

%natural interest rate
RN=zeros(3*T+1,1);
RN(1,1)=nat_int_rate;
for ii=2:3*T+1;
   RN(ii,1)=shock(ii-1,1);
end;

%5 SUMMARIZE AND EVALUATE

discount=ones(size(Y,1),1);
for ii=3:size(Y,1)
    discount(ii,1)=beta*discount(ii-1,1);
end
loss = discount.*((Y.^2)*lambda+(PI-pi_star*ones(size(PI,1),1)).^2);
results = [linspace(0,3*T,3*T+1)' Y PI NIR RIR RN PHI1 PHI2 loss];

%6 DISPLAY THE RESULTS

if showplot==1

	annot_text_1=['Period 0: steady state' 10 'Period 1: shock occurs' 10 'Period ' num2str(T) ': lower bound no more binding'];
	annot_text_2=['Period 0: steady state' 10 'Period 1: shock occurs' 10 'Period ' num2str(T) ': lower bound no more binding'];

	figure(1)
	plot(0:3*T,NIR(:,1),'-k',0:3*T,RN(:,1),':k',0:3*T,RIR(:,1),'--k',0:3*T,PI(:,1),'-.k')
	legend('nominal interest rate','natural interest rate','real interest rate (ex ante)','inflation rate')
	title('Interest rates and inflation - commitment')
	axis([0 3*T -0.05 0.05])
	text(10,-0.02,annot_text_1);
	saveas(1,'Graphs/1_IRF_rates_pi_com.jpg','jpg');
    descr={'nominal interest rate','natural interest rate','real interest rate (ex ante)','inflation rate'};
    xlswrite('Graphs/data.xlsx',descr,1,'B1');
    xlswrite('Graphs/data.xlsx',[NIR(:,1),RN(:,1),RIR(:,1),PI(:,1)],1,'B2');
    %display(annot_text_1);

	figure(2)
	plot(0:3*T,Y,'-k',0:3*T,PHI1*100,'--k',0:3*T,PHI2,':k')
	title('Output gap and Lagrange multipliers - commitment')
	legend('output gap','Lagrange multiplier 1 (*10^2)','Lagrange multiplier 2');
	%axis([0 3*T -0.4 0.3])
	text(8,-0.15,annot_text_2);
	saveas(2,'Graphs/2_IRF_output_phi_pi_com.jpg','jpg');
    descr={'output gap','Lagrange multiplier 1 (*10^2)','Lagrange multiplier 2'};
    xlswrite('Graphs/data.xlsx',descr,2,'B1');
    xlswrite('Graphs/data.xlsx',[Y,PHI1*100,PHI2],2,'B2');

    display(['Commitment: loss function value: ' num2str(sum(loss)) ' as compared to ' num2str(baseline_loss) ' under ZLB']);
    
end


