function [M,N]=solve_model(A,B,n1)

    %
    %Use Klein's (2000) method to compute solution for the system:
    %A*E_t(X_(t+1))=B*X_t
    %in terms of the law of motion for the vector of predetermined
    %variables:
    %X1(t+1) = M*X1_t
    %n1 - number of predetermined variables
    %

    [S,T,Q,Z] = qz(A,B);
    [S,T,Q,Z] = reorder(S,T,Q,Z);
    numeig = abs(diag(T)) <= (abs(diag(S)));

    if sum(numeig) < n1;
      warning('Too few stable roots: no stable solution');
      M = NaN; N = NaN;
      return;
    elseif sum(numeig) > n1;
      warning('Too many stable roots: inifite number of stable solutions');
      M = NaN; N = NaN;
      return;
    end;
    
    S11 = S(1:n1,1:n1);
    Z11 = Z(1:n1,1:n1);
    T11 = T(1:n1,1:n1);
    
    %if cond(Z11) > 1e+10;
    %  warning('Zkt is singular: rank condition for solution not satisfied');
    %  M = NaN; N = NaN;
    %  return;
    %end;
    
    M = real((Z11/S11)*(T11/Z11)) ;      

   
